@charset "UTF-8";
.clearfix:after {
  visibility: hidden;
  display: block;
  font-size: 0;
  content: " ";
  clear: both;
  height: 0;
}

.clearfix {
  display: inline-block;
}

* html .clearfix {
  height: 1%;
}

.clearfix {
  display: block;
}

html, body, div, span, applet, object, iframe,
h1, h2, h3, h4, h5, h6, p, blockquote, pre,
a, abbr, acronym, address, big, cite, code,
del, dfn, em, font, img, ins, kbd, q, s, samp,
small, strike, strong, sub, sup, tt, var,
dl, dt, dd, ol, ul, li,
fieldset, form, label, legend,
table, caption, tbody, tfoot, thead, tr, th, td {
  margin: 0;
  padding: 0;
  border: 0;
  font-weight: inherit;
  font-style: inherit;
  font-size: 100%;
  vertical-align: baseline;
}

body {
  line-height: 1;
  color: black;
}

ol, ul {
  list-style: none;
}

table {
  border-collapse: separate;
  border-spacing: 0;
}

caption, th, td {
  text-align: left;
  font-weight: normal;
}

blockquote:before, blockquote:after,
q:before, q:after {
  content: "";
}

blockquote, q {
  quotes: "" "";
}

command, datalist, source {
  display: none;
}

article, aside, figure, figcaption, footer, header, hgroup, menu, nav, section, summary {
  display: block;
}

figure, menu {
  margin-top: 1em;
  margin-bottom: 1em;
}

dl menu, menu dl, menu menu, menu ol, menu ul {
  margin-top: 0;
  margin-bottom: 0;
}

strong, b {
  font-weight: bold;
}

em, i {
  font-style: italic;
}

h1, h2, h3, h4, h5, h6 {
  font-weight: normal;
}

.ie7 address {
  font-style: normal;
}

.hideme {
  position: absolute;
  left: -999em;
  top: -999em;
}

label,
input[type=button],
input[type=submit],
button {
  cursor: pointer;
}

q:lang(de) {
  quotes: "â€ž" "â€œ" "â€š" "â€˜";
}

q:lang(en) {
  quotes: "â€œ" "â€" "â€˜" "â€™";
}

abbr[title] {
  border-bottom: 1px dotted #888 !important;
  cursor: help;
}

a abbr {
  cursor: pointer !important;
}

.clearfix:after {
  clear: both;
  content: ".";
  display: block;
  height: 0;
  visibility: hidden;
}

.clearfix {
  display: block;
}

img {
  -ms-interpolation-mode: bicubic;
}

body:not(.home) .menu-invisible {
  display: none;
}
body:not(.home) .main-menu .name {
  font-size: 36px;
  text-transform: uppercase;
  padding: 2px 9px;
}
body:not(.home) .main-menu .name2 {
  display: none;
}

body.scrolled .header-header__bg {
  opacity: 1;
}
body.scrolled .header-header .logo {
  opacity: 1 !important;
}

body:not(.home) .header-header__bg {
  opacity: 1 !important;
}
body:not(.home) .header-header .logo {
  opacity: 1 !important;
}

.header-header {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  z-index: 1000;
  line-height: 0.85;
  display: flex;
  align-items: center;
}
@media (max-width: 1050px) {
  .header-header {
    font-size: 18px;
    position: absolute;
  }
}
.header-header .logo {
  display: flex;
  padding: 8px 10px 13px 8px;
  background: white;
}
@media (max-width: 1050px) {
  .header-header .logo {
    padding: 6px 8px 8px 6px;
  }
}
.header-header .logo > a {
  display: inline-block;
  z-index: 1;
  text-transform: uppercase;
  transition: opacity 0.3s;
  font-family: ABCGravity;
  line-height: 0;
}
.header-header .logo > a > svg {
  width: auto;
  height: 80px;
  line-height: 0;
  background: white;
}
@media (max-width: 1050px) {
  .header-header .logo > a > svg {
    height: 50px;
  }
}
.header-header .logo__more {
  display: inline-block;
  font-weight: bold;
  border-width: 0;
  padding: 0 5px 0 15px;
  margin: 0;
  font-size: 118px;
  text-transform: uppercase;
  font-family: ABCGravity;
  -webkit-text-stroke-width: 1.5px;
  -webkit-text-stroke-color: black;
  color: transparent;
  white-space: nowrap;
  letter-spacing: 1.8px;
}
@media (max-width: 1050px) {
  .header-header .logo__more {
    -webkit-text-stroke-width: 1px;
    display: none;
  }
}
.header-header #menu-mobile-button {
  position: absolute;
  top: 8px;
  right: 7px;
  z-index: 3;
  cursor: pointer;
  display: none;
  padding: 7px 12px 4px;
  border-radius: 20px;
  background: black;
  color: white;
  font-weight: bold;
  text-transform: uppercase;
  font-size: 15px;
}
@media (max-width: 1050px) {
  .header-header #menu-mobile-button {
    display: block;
  }
}
.header-header .beta {
  display: inline-block;
  vertical-align: top;
  border: 2px solid;
  padding: 4px 16px 1px 16px;
  line-height: 1;
  font-size: 24px;
  border-radius: 24px;
  margin-top: 5px;
  margin-left: -9px;
  background: black;
  color: white;
}
.header-header .mainmenu {
  display: flex;
  padding: 4px 0px 9px 10px;
  transition: 0.3s -webkit-transform;
  transition: 0.3s transform;
  transition: 0.3s transform, 0.3s -webkit-transform;
  flex-direction: column;
  justify-content: center;
  flex-grow: 1;
  position: relative;
  font-size: 16px;
}
@media (max-width: 1050px) {
  .header-header .mainmenu {
    font-size: 15px;
    display: none;
    position: absolute;
    width: 100%;
    padding: 57px 8px 200px 8px;
    background: linear-gradient(0deg, rgba(255, 255, 255, 0) 0%, rgb(255, 255, 255) 100%);
    top: 0;
  }
}
.header-header .mainmenu--is-visible {
  display: block;
}
.header-header .mainmenu__visitnow {
  height: auto;
  padding: 9px 11px 7px;
  display: inline-block;
  margin-bottom: 0px;
  display: inline-block;
  z-index: 1;
  transition: opacity 0.3s;
  background: black;
  color: white;
  white-space: nowrap;
  letter-spacing: 0;
  border: 1.5px solid transparent;
  border-radius: 90px;
  font-weight: bold;
  right: 0;
  margin-top: 48px;
  display: none;
  position: absolute;
}
@media (max-width: 1050px) {
  .header-header .mainmenu__visitnow {
    font-size: 0.8rem;
    border: 0 none;
  }
}
@media (max-width: 1050px) {
  .header-header .mainmenu__visitnow {
    display: none;
  }
}
.header-header .mainmenu__top {
  border-bottom: 1.5px solid;
  padding-bottom: 15px;
  margin-bottom: 6px;
  font-weight: bold;
  display: flex;
  align-content: center;
  align-items: center;
  justify-content: space-between;
  padding-left: 7px;
  margin-left: -8px;
  padding: 10px 0 10px 8px;
}
@media (max-width: 1250px) {
  .header-header .mainmenu__top {
    font-size: 12px;
    border-width: 0.8px;
  }
}
@media (max-width: 1050px) {
  .header-header .mainmenu__top {
    border-width: 1px;
    display: none;
  }
}
.header-header .mainmenu__top > div {
  flex-grow: 1;
}
.header-header .mainmenu__top > div > div {
  display: inline-block;
}
.header-header .mainmenu__top > div .slideshowheadertext {
  height: 29px;
  margin: -7px 33px -9px 25px;
  max-width: 360px;
}
@media (max-width: 1250px) {
  .header-header .mainmenu__top > div .slideshowheadertext {
    height: 23px;
  }
}
@media (max-width: 1050px) {
  .header-header .mainmenu__top > div .slideshowheadertext {
    height: 25px;
  }
}
.header-header .mainmenu__top > div .slideshowheadertext .swiper-wrapper > .swiper-slide {
  width: 500px;
  padding: 9px 0;
  height: 100%;
  position: relative;
}
.header-header .mainmenu__bottom {
  display: flex;
  justify-content: space-between;
  padding: 10px 0;
}
.header-header .mainmenu__bottom .menu-main-left-container {
  margin-top: -2px;
  margin-bottom: -5px;
  margin-left: -8px;
}
@media (max-width: 1050px) {
  .header-header .mainmenu__bottom .menu-main-left-container {
    width: 100%;
    margin: 0;
  }
}
.header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu {
  margin-left: 8px;
}
@media (max-width: 1050px) {
  .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu {
    display: flex;
    width: 100%;
    align-items: center;
    justify-content: center;
    flex-grow: 0;
    flex-shrink: 0;
    flex: 0 0 100%;
    margin-left: 0;
  }
}
.header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li {
  display: inline-block;
  margin: 0 10px;
  position: relative;
  cursor: pointer;
  transition: 0.3s background, 0.3s color;
}
@media (max-width: 1050px) {
  .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li {
    flex-shrink: 0;
    display: block;
    margin: 2px;
    padding: 7px 12px 4px;
    border-radius: 20px;
    background: white;
    color: black;
    font-weight: bold;
    border: 1.5px solid black;
    flex-grow: 1;
    text-align: center;
  }
  .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li a {
    color: black;
  }
  .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li a span.act {
    display: block;
  }
}
.header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li:first-child {
  margin-left: 2px;
}
@media (max-width: 1050px) {
  .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li:first-child {
    margin-left: 0px;
  }
}
.header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li:last-child {
  margin-right: 0px;
}
@media (max-width: 1050px) {
  .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li:last-child {
    margin-right: 0px;
  }
}
@media (max-width: 1050px) {
  .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li:hover, .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li.current_page_item, .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li.current-menu-item {
    background: black;
    color: white;
    border-color: black;
  }
}
.header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li:hover a span.act, .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li.current_page_item a span.act, .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li.current-menu-item a span.act {
  display: block;
}
.header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li:hover a span.inact, .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li.current_page_item a span.inact, .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li.current-menu-item a span.inact {
  opacity: 0;
}
@media (max-width: 1050px) {
  .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li:hover a span.inact, .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li.current_page_item a span.inact, .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li.current-menu-item a span.inact {
    display: none;
  }
}
.header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li a {
  border-radius: 6px;
  height: auto;
  display: inline-block;
  margin-top: -10px;
  margin-bottom: -40px;
  display: inline-block;
  z-index: 1;
  transition: opacity 0.3s;
  white-space: nowrap;
  letter-spacing: 0;
  text-transform: uppercase;
}
.header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li a span.act {
  display: none;
  position: absolute;
  top: -8px;
  left: -11px;
  padding: 8px 0px;
  text-align: center;
  width: calc(100% + 22px);
  height: calc(100% + 14px);
  font-weight: bold;
}
@media (max-width: 1050px) {
  .header-header .mainmenu__bottom .menu-main-left-container ul#primary-menu li a span.act {
    padding: initial;
    position: initial;
    width: initial;
    color: white;
  }
}

.home .login {
  display: none;
}

#colophon {
  pointer-events: none;
  visibility: hidden;
  position: static !important;
}

.site-footer {
  width: 100%;
  display: block;
  padding: 0 0 120px 0;
  border-top: 2px solid black;
  font-size: 18px;
  bottom: 0;
  position: fixed;
  left: 0;
  pointer-events: auto;
  z-index: -1;
  background: black;
  color: white;
  line-height: 1.2;
}
@media (max-width: 1050px) {
  .site-footer {
    padding-bottom: 15px;
    font-size: 15px;
  }
}
.site-footer > div {
  padding: 24px;
  display: flex;
  width: 100%;
  flex-direction: row;
  justify-content: space-between;
  align-items: stretch;
}
@media (max-width: 700px) {
  .site-footer > div {
    flex-wrap: wrap;
  }
}
@media (max-width: 700px) {
  .site-footer > div > div.site-footer__devices {
    flex: 1 0 100%;
  }
}
@media (max-width: 700px) {
  .site-footer > div > div {
    flex: 1 0 49%;
    margin-bottom: 24px;
  }
}
.site-footer p {
  margin: 0 0 6px 0;
}
.site-footer__menu a:not(.name) {
  display: inline-block;
  border-bottom: 1px solid;
}
.site-footer__devices .realthings a {
  border: 0 none;
  text-decoration: none;
  padding: 5px 12px 2px;
  border-radius: 20px;
  background: #868686;
  color: black;
  font-weight: bold;
  font-size: 18px;
  font-style: italic;
  margin-top: 6px;
  display: inline-block;
  margin-bottom: 22px;
}
.site-footer__devices__block {
  margin-bottom: 12px;
  width: 100%;
  display: flex;
}
.site-footer__devices__block__device {
  padding: 0 6px;
  position: relative;
}
.site-footer__devices__block__device:first-child {
  padding-left: 0;
}
.site-footer__devices__block__device > div {
  border: 1px solid rgba(255, 255, 255, 0.3);
  height: 50px;
  padding: 9px 12px;
}
.site-footer__devices__block__device > div img {
  width: auto;
  height: 100%;
  line-height: 0;
}
.site-footer__devices .unavailable {
  opacity: 0.5;
}
.site-footer__copyright {
  padding-right: 72px;
}
.site-footer__some__handle {
  display: inline-block;
  margin: 0 6px 0 0;
  padding: 3px;
}
.site-footer__some__handle > div {
  border: 1px solid rgba(255, 255, 255, 0.3);
  padding: 8px;
  display: inline-block;
  line-height: 0;
}
.site-footer__some__handle > div img {
  width: 30px;
  height: 30px;
  line-height: 1;
}

body.cookiePolicy-shown #cookiebar {
  display: flex;
}

#cookiebar {
  position: fixed;
  bottom: 50px;
  left: 50%;
  right: 0;
  background: rgba(0, 0, 0, 0.2);
  display: none;
  z-index: 10000;
  align-items: stretch;
  max-width: 560px;
  margin-left: -200px;
  -webkit-backdrop-filter: blur(4px);
          backdrop-filter: blur(4px);
  border-radius: 12px;
  color: rgb(20, 20, 20);
}
#cookiebar .cookies-left {
  padding: 15px;
  width: 75%;
  border-right: 1px solid rgba(0, 0, 0, 0.1);
  font-size: 0.9rem;
  color: white;
}
#cookiebar .cookies-left a {
  color: rgba(255, 255, 255, 0.6);
  display: inline-block;
  border-bottom: 1px solid rgba(255, 255, 255, 0.6);
  font-size: 0.9rem;
}
#cookiebar > a {
  padding: 15px;
  width: 25%;
  align-self: stretch;
  font-size: 0.9rem;
  display: flex;
  border-bottom: 0 none;
  color: white;
  transition: 0.3s background, 0.3s color;
  border-radius: 0 12px 12px 0;
}
#cookiebar > a:hover {
  background: rgba(0, 0, 0, 0.5);
}
#cookiebar > a span {
  align-self: center;
  width: 100%;
  text-align: center;
  display: block;
  font-size: 0.9rem;
}

.labelGenerated {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  pointer-events: none;
}
.labelGenerated .label {
  position: absolute;
  font-size: 12px;
}

.blog #main {
  display: flex;
  flex-grow: 1;
  flex-basis: 0;
  padding: 6px;
  flex-wrap: wrap;
}
.blog #main article {
  flex: 3 0 33%;
  padding: 6px;
}
.blog #main article header h2 {
  line-height: 1;
}

#left-container, #right-container {
  position: fixed;
  z-index: 100;
  left: 0;
  width: 50%;
  top: 0;
  bottom: 0;
  pointer-events: none;
}
#left-container > div, #right-container > div {
  background: #eee;
  height: 100%;
  padding: 12px;
  overflow-y: scroll;
  -webkit-transform: translateX(-100%);
          transform: translateX(-100%);
  transition: 0.3s -webkit-transform;
  transition: 0.3s transform;
  transition: 0.3s transform, 0.3s -webkit-transform;
  pointer-events: auto;
  position: absolute;
  width: 100%;
  top: 0;
  left: 0;
  padding-top: 12px;
}
#left-container > div.act, #right-container > div.act {
  -webkit-transform: translateX(0);
          transform: translateX(0);
}
#left-container > div > div.list-exhibition ul li, #right-container > div > div.list-exhibition ul li {
  width: 100%;
}
#left-container > div > div.list-exhibition ul li > div.title, #right-container > div > div.list-exhibition ul li > div.title {
  width: 35%;
}
#left-container > div > div.list-exhibition ul li > div.artists, #right-container > div > div.list-exhibition ul li > div.artists {
  display: none;
}
#left-container > div > div.list-exhibition ul li > div.locations, #right-container > div > div.list-exhibition ul li > div.locations {
  width: 25%;
}
#left-container > div > div.list-exhibition ul li > div.cities, #right-container > div > div.list-exhibition ul li > div.cities {
  width: 25%;
}
#left-container > div > div.list-exhibition ul li > div.media, #right-container > div > div.list-exhibition ul li > div.media {
  width: 20%;
}
#left-container > div > div.list-location ul li, #right-container > div > div.list-location ul li {
  width: 100%;
}
#left-container > div > div.list-location ul li > div.title, #right-container > div > div.list-location ul li > div.title {
  width: 50%;
}
#left-container > div > div.list-location ul li > div.artists, #right-container > div > div.list-location ul li > div.artists {
  display: none;
}
#left-container > div > div.list-location ul li > div.locations, #right-container > div > div.list-location ul li > div.locations {
  display: none;
}
#left-container > div > div.list-location ul li > div.cities, #right-container > div > div.list-location ul li > div.cities {
  width: 50%;
}
#left-container > div > div.list-location ul li > div.media, #right-container > div > div.list-location ul li > div.media {
  display: none;
}
#left-container > div > div.list-artist ul, #right-container > div > div.list-artist ul {
  -webkit-columns: 3;
     -moz-columns: 3;
          columns: 3;
}
#left-container > div > div.list-artist ul li, #right-container > div > div.list-artist ul li {
  width: 100%;
}
#left-container > div > div.list-artist ul li > div, #right-container > div > div.list-artist ul li > div {
  display: none;
  width: 100%;
}
#left-container > div > div.list-artist ul li > div.title, #right-container > div > div.list-artist ul li > div.title {
  display: block;
}
#left-container > div h2, #right-container > div h2 {
  margin-bottom: 48px;
  margin-left: 0px;
}
#left-container > div .close, #right-container > div .close {
  position: absolute;
  top: 2px;
  right: 12px;
  cursor: pointer;
}
#left-container > div ul, #right-container > div ul {
  list-style-type: none;
}
#left-container > div ul.header li, #right-container > div ul.header li {
  border-bottom: 0 none;
}
#left-container > div ul.header li div, #right-container > div ul.header li div {
  font-family: manuelrossner-std-med;
  text-transform: uppercase;
  margin-bottom: 12px;
}
#left-container > div ul li, #right-container > div ul li {
  font-size: 1.1rem;
  line-height: 1.1;
  border-bottom: 1px solid #e2e2e2;
  padding: 6px 0 6px 0;
  display: flex;
}
#left-container > div ul li > div, #right-container > div ul li > div {
  padding: 0 6px;
  width: 23%;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
}
#left-container > div ul li > div:first-child, #right-container > div ul li > div:first-child {
  font-family: manuelrossner-std-med;
  width: 40%;
}
#left-container > div ul li > div.cities, #right-container > div ul li > div.cities {
  width: 13%;
}
#left-container > div ul li > div.media, #right-container > div ul li > div.media {
  overflow: hidden;
  white-space: nowrap;
}
#left-container > div ul li > div.media > div, #right-container > div ul li > div.media > div {
  display: inline-block;
  font-size: 0.75rem;
  text-transform: uppercase;
  margin-right: 6px;
  border: 1px solid;
  padding: 4px 9px;
  border-radius: 19px;
}

#right-container {
  left: initial;
  right: 0;
}
#right-container > div {
  -webkit-transform: translateX(100%);
          transform: translateX(100%);
}

body.single-artwork {
  font-size: 21px !important;
}
body.single-artwork #primary {
  z-index: 10;
}
body.single-artwork #content .marquee-container {
  height: calc(100vh - 375px);
  top: initial;
  position: relative;
}
@media (max-width: 1050px) {
  body.single-artwork #content .marquee-container {
    z-index: 0;
    height: 100vh;
  }
}
body.single-artwork .single-artwork {
  padding: 0 0px;
}
body.single-artwork .single-artwork__header h2 {
  overflow-wrap: break-word;
  word-wrap: break-word;
  line-height: 0.8;
  margin-left: 0;
}
body.single-artwork .single-artwork__header h2.font-size-xl {
  font-size: 7vw;
}
body.single-artwork .single-artwork__header h2.font-size-l {
  font-size: 5vw;
}
body.single-artwork .single-artwork__header h2 span.authorname {
  font-style: italic;
}
body.single-artwork .single-artwork__viewer {
  width: 100%;
  height: calc(100vh - 360px);
  padding: 0 0 15px 0;
  line-height: 0;
}
@media (max-width: 1050px) {
  body.single-artwork .single-artwork__viewer {
    padding: 0;
  }
}
body.single-artwork .single-artwork__viewer img {
  width: 100%;
  height: 100%;
  -o-object-fit: contain;
     object-fit: contain;
  -o-object-position: left top;
     object-position: left top;
}
@media (max-width: 1050px) {
  body.single-artwork .single-artwork h3 {
    font-size: 24px;
    margin-bottom: 2px;
  }
}
body.single-artwork .single-artwork__content {
  margin-left: -120px;
  background: #000;
}
@media (max-width: 1050px) {
  body.single-artwork .single-artwork__content {
    margin-left: -90px;
  }
}
body.single-artwork .single-artwork__content > * {
  vertical-align: top;
  display: inline-block;
}
body.single-artwork .single-artwork__content__header {
  max-width: 50%;
  padding: 0 15px 15px 0;
}
@media (max-width: 1050px) {
  body.single-artwork .single-artwork__content__header {
    padding: 15px 25px;
    max-width: 100%;
  }
}
body.single-artwork .single-artwork__content__header > div {
  padding: 15px;
  border: 1.5px solid;
  border-radius: 15px;
}
body.single-artwork .single-artwork__content .descr_text {
  max-width: 33.33%;
  color: white;
  padding: 0 15px 15px 0;
  vertical-align: top;
}
@media (max-width: 1050px) {
  body.single-artwork .single-artwork__content .descr_text {
    max-width: 100%;
    display: block;
    padding: 0 25px 25px 25px;
  }
}
body.single-artwork .single-artwork__content .descr_text > div {
  background: rgb(18, 18, 18);
  padding: 15px 20px;
  border-radius: 15px;
}
body.single-artwork .single-artwork__content .descr_text > div p {
  padding-left: 0 !important;
  margin: 0 !important;
  padding: 0 !important;
}
body.single-artwork .single-artwork__content .artist {
  display: inline-block;
  font-weight: bold;
  border-width: 0;
  padding: 0;
  margin: 0;
  font-size: 8vw;
  text-transform: uppercase;
  font-family: ABCGravity;
  color: white;
  line-height: 0.8;
}
@media (max-width: 1050px) {
  body.single-artwork .single-artwork__content .artist {
    font-weight: normal;
    font-size: 13vw;
  }
}
body.single-artwork .single-artwork__content h3 + p {
  margin-top: 0;
  padding-top: 0 !important;
}
body.single-artwork .single-artwork__meta {
  width: 20%;
  padding: 0 15px 15px 0;
}
@media (max-width: 1050px) {
  body.single-artwork .single-artwork__meta {
    width: 100%;
    padding: 0 25px;
  }
}
body.single-artwork .single-artwork__meta__header {
  font-style: normal;
  background-color: transparent;
  padding: 10px 15px;
  margin: 0;
  width: 100%;
  border-bottom: 1.5px solid black;
  text-align: center;
  text-transform: uppercase;
  font-size: 1.2rem;
}
@media (max-width: 1050px) {
  body.single-artwork .single-artwork__meta__header {
    font-size: 21px !important;
  }
}
body.single-artwork .single-artwork__meta > div {
  background: rgb(18, 18, 18);
  border-radius: 15px;
}
body.single-artwork .single-artwork__meta > div > div {
  display: flex;
}
body.single-artwork .single-artwork__meta > div > div:last-child > * {
  padding-bottom: 22px;
}
body.single-artwork .single-artwork__meta > div > div > * {
  width: 50%;
  display: flex;
  flex-grow: 0;
  border-bottom: 1.5px solid black;
  padding: 5px 15px;
}
body.single-artwork .single-artwork__meta > div > div > div:nth-child(1) {
  border-right: 1px solid black;
}
body.single-artwork .single-artwork__meta > div > div > div:nth-child(2) a {
  display: inline-block;
  vertical-align: top;
  border: 1.5px solid;
  padding: 7px 12px 1px 12px;
  font-size: initial;
  border-radius: 24px;
  margin-top: -2px;
  margin-left: -4px;
  color: white;
  line-height: 0.9;
  transition: 0.3s color, 0.3s background-color;
  font-weight: bold;
  font-size: 0.8rem;
  border-color: white;
}
body.single-artwork .single-artwork__meta > div > div > div:nth-child(2) a:hover {
  color: #000;
  background-color: white;
}
@media (max-width: 700px) {
  body.single-artwork .single-artwork__meta > div {
    font-size: 21px;
    margin-top: -5px;
  }
}
body.single-artwork .single-artwork__tags {
  padding: 0 15px 15px 0;
  width: 20%;
}
@media (max-width: 1050px) {
  body.single-artwork .single-artwork__tags {
    width: 100%;
    padding: 12px 25px 12px 30px;
  }
}
body.single-artwork .single-artwork__tags h3 {
  background: rgb(18, 18, 18);
  font-size: 1.2rem;
  border-radius: 24px;
  padding: 8px 16px 5px 16px;
  margin-bottom: 6px;
  margin-left: -4px;
  display: inline-block;
  width: initial;
}
body.single-artwork .single-artwork__tags a {
  display: inline-block;
  vertical-align: top;
  border: 1.5px solid;
  padding: 6px 16px 3px 16px;
  line-height: 1;
  font-size: 1.2rem;
  border-radius: 24px;
  margin-top: 3px;
  margin-left: -4px;
  margin-right: 9px;
  margin-bottom: 6px;
  background: black;
  color: white;
  text-transform: uppercase;
  transition: 0.3s color, 0.3s background-color;
}
body.single-artwork .single-artwork__tags a:hover {
  color: #000;
  background-color: white;
}
@media (max-width: 700px) {
  body.single-artwork .single-artwork__tags a {
    font-size: 21px;
  }
}
body.single-artwork .single-artwork__moreworks {
  background: #000;
  line-height: 1.1;
  margin-left: -120px;
}
@media (max-width: 1050px) {
  body.single-artwork .single-artwork__moreworks {
    margin-left: -60px;
  }
}
body.single-artwork .single-artwork__moreworks__header {
  background: rgb(18, 18, 18);
  padding: 8px 21px 8px 21px;
  margin-bottom: 15px;
  margin-left: -4px;
  display: inline-block;
  width: initial;
  border-radius: 24px;
  font-size: 21px !important;
}
body.single-artwork .single-artwork__moreworks__artist {
  font-weight: bold;
  text-transform: uppercase;
}
body.single-artwork .single-artwork__moreworks__works {
  display: flex;
  flex-wrap: wrap;
  width: 100%;
}
body.single-artwork .single-artwork__moreworks__works > * {
  width: 20%;
  flex-grow: 0;
  padding: 0 15px 15px 0;
}
@media (max-width: 1050px) {
  body.single-artwork .single-artwork__moreworks__works > * {
    width: 50%;
  }
}
body.single-artwork .single-artwork__moreworks__works > * > div {
  background: rgb(18, 18, 18);
  line-height: 1.1;
  padding: 12px 12px 18px 12px;
  border: 1px solid rgba(0, 0, 0, 0.02);
  border-radius: 15px;
}
body.single-artwork .single-artwork__moreworks__works > * > div img {
  margin-bottom: 12px;
}
body.single-artwork .single-artwork__adjacent {
  margin-top: 36px;
  margin-left: -120px;
}
@media (max-width: 1050px) {
  body.single-artwork .single-artwork__adjacent {
    margin-left: -60px;
    width: 100%;
    overflow: hidden;
  }
}
body.single-artwork .single-artwork__adjacent__works {
  width: 100%;
  display: flex;
}
@media (max-width: 1050px) {
  body.single-artwork .single-artwork__adjacent__works {
    width: 100%;
    display: block;
  }
}
body.single-artwork .single-artwork__adjacent__works > * {
  flex: 1 0 50%;
  display: flex;
  align-content: center;
  justify-content: center;
  align-items: center;
  padding: 7px;
}
body.single-artwork .single-artwork__adjacent__works > * > a {
  display: flex;
  align-items: center;
  flex-direction: column;
  background: rgb(18, 18, 18);
  width: 100%;
  height: 100%;
  padding: 72px 0;
  border-radius: 24px;
  font-size: 1.2rem;
  line-height: 0.9;
  text-align: left;
}
@media (max-width: 1050px) {
  body.single-artwork .single-artwork__adjacent__works > * > a {
    font-size: 18px;
  }
}
body.single-artwork .single-artwork__adjacent__works > * > a img {
  max-width: 300px;
}
@media (max-width: 1050px) {
  body.single-artwork .single-artwork__adjacent__works > * > a img {
    max-width: 100px;
  }
}
body.single-artwork .single-artwork__adjacent__works > * > a > div.artists {
  font-weight: bold;
  padding: 12px;
  text-transform: uppercase;
}
body.single-artwork .single-artwork__adjacent__works > * > a > div.artists.arr {
  font-weight: 300;
  font-size: 64px;
}
body.single-artwork h3 {
  font-style: normal;
  background-color: transparent;
  padding: 10px 0px;
  margin: 0;
  width: 100%;
  border-bottom: 1.5px solid black;
  text-align: left;
  text-transform: uppercase;
  font-size: 1.2rem;
}

/**
 * * Swiper 8.4.4
 * * Most modern mobile touch slider and framework with hardware accelerated transitions
 * * https://swiperjs.com
 * *
 * * Copyright 2014-2022 Vladimir Kharlampidi
 * *
 * * Released under the MIT License
 * *
 * * Released on: October 12, 2022
 * */
@font-face {
  font-family: swiper-icons;
  src: url("data:application/font-woff;charset=utf-8;base64, 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");
  font-weight: 400;
  font-style: normal;
}
:root {
  --swiper-theme-color: #007aff;
}

.swiper {
  margin-left: auto;
  margin-right: auto;
  position: relative;
  overflow: hidden;
  list-style: none;
  padding: 0;
  z-index: 1;
}
.swiper-vertical > .swiper-wrapper {
  flex-direction: column;
}
.swiper-wrapper {
  position: relative;
  width: 100%;
  height: 100%;
  z-index: 1;
  display: flex;
  transition-property: -webkit-transform;
  transition-property: transform;
  transition-property: transform, -webkit-transform;
  box-sizing: content-box;
}
.swiper-android .swiper-slide, .swiper .swiper-wrapper {
  -webkit-transform: translate3d(0px, 0, 0);
          transform: translate3d(0px, 0, 0);
}
.swiper-pointer-events {
  touch-action: pan-y;
}
.swiper-pointer-events-vertical {
  touch-action: pan-x;
}
.swiper-slide {
  flex-shrink: 0;
  width: 100%;
  height: 100%;
  position: relative;
  transition-property: -webkit-transform;
  transition-property: transform;
  transition-property: transform, -webkit-transform;
}
.swiper-slide-invisible-blank {
  visibility: hidden;
}
.swiper-autoheight {
  height: auto;
}
.swiper-autoheight-slide {
  height: auto;
}
.swiper-autoheight-wrapper {
  align-items: flex-start;
  transition-property: height, -webkit-transform;
  transition-property: transform, height;
  transition-property: transform, height, -webkit-transform;
}
.swiper-backface-hidden .swiper-slide {
  -webkit-transform: translateZ(0);
          transform: translateZ(0);
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
}
.swiper-3d {
  -webkit-perspective: 1200px;
          perspective: 1200px;
}
.swiper-3d-css-mode .swiper-wrapper {
  -webkit-perspective: 1200px;
          perspective: 1200px;
}
.swiper-3d-cube-shadow, .swiper-3d .swiper-slide, .swiper-3d .swiper-slide-shadow, .swiper-3d .swiper-slide-shadow-bottom, .swiper-3d .swiper-slide-shadow-left, .swiper-3d .swiper-slide-shadow-right, .swiper-3d .swiper-slide-shadow-top, .swiper-3d .swiper-wrapper {
  -webkit-transform-style: preserve-3d;
          transform-style: preserve-3d;
}
.swiper-3d-slide-shadow, .swiper-3d .swiper-slide-shadow-bottom, .swiper-3d .swiper-slide-shadow-left, .swiper-3d .swiper-slide-shadow-right, .swiper-3d .swiper-slide-shadow-top {
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  pointer-events: none;
  z-index: 10;
}
.swiper-3d-slide-shadow {
  background: rgba(0, 0, 0, 0.15);
}
.swiper-3d-slide-shadow-left {
  background-image: linear-gradient(to left, rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0));
}
.swiper-3d-slide-shadow-right {
  background-image: linear-gradient(to right, rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0));
}
.swiper-3d-slide-shadow-top {
  background-image: linear-gradient(to top, rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0));
}
.swiper-3d-slide-shadow-bottom {
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0));
}
.swiper-css-mode > .swiper-wrapper {
  overflow: auto;
  scrollbar-width: none;
  -ms-overflow-style: none;
}
.swiper::-webkit-scrollbar {
  display: none;
}
.swiper::-webkit-scrollbar-slide {
  scroll-snap-align: start start;
}
.swiper-horizontal.swiper-css-mode > .swiper-wrapper {
  scroll-snap-type: x mandatory;
}
.swiper-vertical.swiper-css-mode > .swiper-wrapper {
  scroll-snap-type: y mandatory;
}
.swiper-centered-wrapper::before {
  content: "";
  flex-shrink: 0;
  order: 9999;
}
.swiper-centered-horizontal > .swiper-wrapper-slide:first-child {
  -webkit-margin-start: var(--swiper-centered-offset-before);
          margin-inline-start: var(--swiper-centered-offset-before);
}
.swiper-centered::before {
  height: 100%;
  min-height: 1px;
  width: var(--swiper-centered-offset-after);
}
.swiper-centered-vertical > .swiper-wrapper-slide:first-child {
  -webkit-margin-before: var(--swiper-centered-offset-before);
          margin-block-start: var(--swiper-centered-offset-before);
}
.swiper-centered::before {
  width: 100%;
  min-width: 1px;
  height: var(--swiper-centered-offset-after);
}
.swiper-centered-wrapper > .swiper-slide {
  scroll-snap-align: center center;
}
.swiper-virtual-slide {
  -webkit-backface-visibility: hidden;
  -webkit-transform: translateZ(0);
          transform: translateZ(0);
}
.swiper-virtual-css-mode-wrapper::after {
  content: "";
  position: absolute;
  left: 0;
  top: 0;
  pointer-events: none;
}
.swiper-virtual-css-mode-horizontal .swiper-wrapper::after {
  height: 1px;
  width: var(--swiper-virtual-size);
}
.swiper-virtual-css-mode-vertical .swiper-wrapper::after {
  width: 1px;
  height: var(--swiper-virtual-size);
}

:root {
  --swiper-navigation-size: 44px;
  --swiper-preloader-color: #fff;
  --swiper-preloader-color: #000;
}
:root-button-next, :root .swiper-button-prev {
  position: absolute;
  top: 50%;
  width: calc(var(--swiper-navigation-size) / 44 * 27);
  height: var(--swiper-navigation-size);
  margin-top: calc(0px - var(--swiper-navigation-size) / 2);
  z-index: 10;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  color: var(--swiper-navigation-color, var(--swiper-theme-color));
}
:root-button-next.swiper-button-disabled, :root .swiper-button-prev.swiper-button-disabled {
  opacity: 0.35;
  cursor: auto;
  pointer-events: none;
}
:root-button-next.swiper-button-hidden, :root .swiper-button-prev.swiper-button-hidden {
  opacity: 0;
  cursor: auto;
  pointer-events: none;
}
:root-navigation-disabled-button-next, :root-navigation-disabled .swiper-button-prev {
  display: none !important;
}
:root-button-next:after {
  font-family: swiper-icons;
  font-size: var(--swiper-navigation-size);
  text-transform: none !important;
  letter-spacing: 0;
  font-variant: initial;
  line-height: 1;
}
:root:after {
  font-family: swiper-icons;
  font-size: var(--swiper-navigation-size);
  text-transform: none !important;
  letter-spacing: 0;
  font-variant: initial;
  line-height: 1;
  left: 10px;
  right: auto;
}
:root-rtl .swiper-button-next {
  left: 10px;
  right: auto;
}
:root-button-prev:after, :root .swiper-rtl .swiper-button-next:after {
  content: "prev";
}
:root-button-next, :root .swiper-rtl .swiper-button-prev {
  right: 10px;
  left: auto;
}
:root-button-next:after, :root .swiper-rtl .swiper-button-prev:after {
  content: "next";
}
:root-button-lock {
  display: none;
}
:root-pagination {
  position: absolute;
  text-align: center;
  transition: 0.3s opacity;
  -webkit-transform: translate3d(0, 0, 0);
          transform: translate3d(0, 0, 0);
  z-index: 10;
}
:root-pagination-pagination-hidden {
  opacity: 0;
}
:root-pagination-disabled > .swiper-pagination, :root .swiper-pagination.swiper-pagination-disabled {
  display: none !important;
}
:root-horizontal > .swiper-pagination-bullets, :root .swiper-pagination-bullets.swiper-pagination-horizontal, :root .swiper-pagination-custom, :root .swiper-pagination-fraction {
  bottom: 10px;
  left: 0;
  width: 100%;
}
:root-pagination-bullets-dynamic {
  overflow: hidden;
  font-size: 0;
}
:root-pagination-bullets-dynamic-pagination-bullet {
  -webkit-transform: scale(0.33);
          transform: scale(0.33);
  position: relative;
}
:root-pagination-bullets-dynamic-pagination-bullet-active, :root-pagination-bullets-dynamic .swiper-pagination-bullet-active-main {
  -webkit-transform: scale(1);
          transform: scale(1);
}
:root-pagination-bullets-dynamic-pagination-bullet-active-prev {
  -webkit-transform: scale(0.66);
          transform: scale(0.66);
}
:root-pagination-bullets-dynamic-pagination-bullet-active-prev-prev {
  -webkit-transform: scale(0.33);
          transform: scale(0.33);
}
:root-pagination-bullets-dynamic-pagination-bullet-active-next {
  -webkit-transform: scale(0.66);
          transform: scale(0.66);
}
:root-pagination-bullets-dynamic-pagination-bullet-active-next-next {
  -webkit-transform: scale(0.33);
          transform: scale(0.33);
}
:root-pagination-bullet {
  width: var(--swiper-pagination-bullet-width, var(--swiper-pagination-bullet-size, 8px));
  height: var(--swiper-pagination-bullet-height, var(--swiper-pagination-bullet-size, 8px));
  display: inline-block;
  border-radius: 50%;
  background: var(--swiper-pagination-bullet-inactive-color, #000);
  opacity: var(--swiper-pagination-bullet-inactive-opacity, 0.2);
}
:root-button-pagination-bullet {
  border: none;
  margin: 0;
  padding: 0;
  box-shadow: none;
  -webkit-appearance: none;
  -moz-appearance: none;
       appearance: none;
}
:root-pagination-clickable .swiper-pagination-bullet {
  cursor: pointer;
}
:root-pagination-bullet:only-child {
  display: none !important;
}
:root-pagination-bullet-active {
  opacity: var(--swiper-pagination-bullet-opacity, 1);
  background: var(--swiper-pagination-color, var(--swiper-theme-color));
}
:root-pagination-vertical.swiper-pagination-bullets, :root .swiper-vertical > .swiper-pagination-bullets {
  right: 10px;
  top: 50%;
  -webkit-transform: translate3d(0px, -50%, 0);
          transform: translate3d(0px, -50%, 0);
}
:root-pagination-vertical.swiper-pagination-bullets .swiper-pagination-bullet, :root .swiper-vertical > .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: var(--swiper-pagination-bullet-vertical-gap, 6px) 0;
  display: block;
}
:root-pagination-vertical.swiper-pagination-bullets.swiper-pagination-bullets-dynamic, :root .swiper-vertical > .swiper-pagination-bullets.swiper-pagination-bullets-dynamic {
  top: 50%;
  -webkit-transform: translateY(-50%);
          transform: translateY(-50%);
  width: 8px;
}
:root-pagination-vertical.swiper-pagination-bullets.swiper-pagination-bullets-dynamic .swiper-pagination-bullet, :root .swiper-vertical > .swiper-pagination-bullets.swiper-pagination-bullets-dynamic .swiper-pagination-bullet {
  display: inline-block;
  transition: 0.2s top, 0.2s -webkit-transform;
  transition: 0.2s transform, 0.2s top;
  transition: 0.2s transform, 0.2s top, 0.2s -webkit-transform;
}
:root-horizontal > .swiper-pagination-bullets .swiper-pagination-bullet, :root .swiper-pagination-horizontal.swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 var(--swiper-pagination-bullet-horizontal-gap, 4px);
}
:root-horizontal > .swiper-pagination-bullets.swiper-pagination-bullets-dynamic, :root .swiper-pagination-horizontal.swiper-pagination-bullets.swiper-pagination-bullets-dynamic {
  left: 50%;
  -webkit-transform: translateX(-50%);
          transform: translateX(-50%);
  white-space: nowrap;
}
:root-horizontal > .swiper-pagination-bullets.swiper-pagination-bullets-dynamic .swiper-pagination-bullet, :root .swiper-pagination-horizontal.swiper-pagination-bullets.swiper-pagination-bullets-dynamic .swiper-pagination-bullet {
  transition: 0.2s left, 0.2s -webkit-transform;
  transition: 0.2s transform, 0.2s left;
  transition: 0.2s transform, 0.2s left, 0.2s -webkit-transform;
}
:root-horizontal.swiper-rtl > .swiper-pagination-bullets-dynamic .swiper-pagination-bullet {
  transition: 0.2s right, 0.2s -webkit-transform;
  transition: 0.2s transform, 0.2s right;
  transition: 0.2s transform, 0.2s right, 0.2s -webkit-transform;
}
:root-pagination-progressbar {
  background: rgba(0, 0, 0, 0.25);
  position: absolute;
}
:root-pagination-progressbar-pagination-progressbar-fill {
  background: var(--swiper-pagination-color, var(--swiper-theme-color));
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  -webkit-transform: scale(0);
          transform: scale(0);
  -webkit-transform-origin: left top;
          transform-origin: left top;
}
:root-rtl .swiper-pagination-progressbar .swiper-pagination-progressbar-fill {
  -webkit-transform-origin: right top;
          transform-origin: right top;
}
:root-horizontal > .swiper-pagination-progressbar {
  width: 100%;
  height: 4px;
  left: 0;
  top: 0;
}
:root-pagination-progressbar-pagination-horizontal, :root-pagination-progressbar.swiper-pagination-vertical.swiper-pagination-progressbar-opposite {
  width: 100%;
  height: 4px;
  left: 0;
  top: 0;
}
:root-vertical > .swiper-pagination-progressbar.swiper-pagination-progressbar-opposite {
  width: 100%;
  height: 4px;
  left: 0;
  top: 0;
}
:root-horizontal > .swiper-pagination-progressbar.swiper-pagination-progressbar-opposite {
  width: 4px;
  height: 100%;
  left: 0;
  top: 0;
}
:root-pagination-progressbar-pagination-horizontal.swiper-pagination-progressbar-opposite, :root-pagination-progressbar.swiper-pagination-vertical {
  width: 4px;
  height: 100%;
  left: 0;
  top: 0;
}
:root-vertical > .swiper-pagination-progressbar {
  width: 4px;
  height: 100%;
  left: 0;
  top: 0;
}
:root-pagination-lock {
  display: none;
}
:root-scrollbar {
  border-radius: 10px;
  position: relative;
  -ms-touch-action: none;
  background: rgba(0, 0, 0, 0.1);
}
:root-scrollbar-disabled > .swiper-scrollbar, :root .swiper-scrollbar.swiper-scrollbar-disabled {
  display: none !important;
}
:root-horizontal > .swiper-scrollbar {
  position: absolute;
  left: 1%;
  bottom: 3px;
  z-index: 50;
  height: 5px;
  width: 98%;
}
:root-scrollbar-scrollbar-horizontal {
  position: absolute;
  left: 1%;
  bottom: 3px;
  z-index: 50;
  height: 5px;
  width: 98%;
}
:root-scrollbar-scrollbar-vertical {
  position: absolute;
  right: 3px;
  top: 1%;
  z-index: 50;
  width: 5px;
  height: 98%;
}
:root-vertical > .swiper-scrollbar {
  position: absolute;
  right: 3px;
  top: 1%;
  z-index: 50;
  width: 5px;
  height: 98%;
}
:root-scrollbar-drag {
  height: 100%;
  width: 100%;
  position: relative;
  background: rgba(0, 0, 0, 0.5);
  border-radius: 10px;
  left: 0;
  top: 0;
}
:root-scrollbar-cursor-drag {
  cursor: move;
}
:root-scrollbar-lock {
  display: none;
}
:root-zoom-container {
  width: 100%;
  height: 100%;
  display: flex;
  justify-content: center;
  align-items: center;
  text-align: center;
}
:root > canvas, :root > img, :root > svg {
  max-width: 100%;
  max-height: 100%;
  -o-object-fit: contain;
     object-fit: contain;
}
:root-slide-zoomed {
  cursor: move;
}
:root-lazy-preloader {
  width: 42px;
  height: 42px;
  position: absolute;
  left: 50%;
  top: 50%;
  margin-left: -21px;
  margin-top: -21px;
  z-index: 10;
  -webkit-transform-origin: 50%;
          transform-origin: 50%;
  box-sizing: border-box;
  border: 4px solid var(--swiper-preloader-color, var(--swiper-theme-color));
  border-radius: 50%;
  border-top-color: transparent;
}
:root-watch-progress .swiper-slide-visible .swiper-lazy-preloader, :root .swiper:not(.swiper-watch-progress) .swiper-lazy-preloader {
  -webkit-animation: swiper-preloader-spin 1s infinite linear;
          animation: swiper-preloader-spin 1s infinite linear;
}
@-webkit-keyframes swiper-preloader-spin {
  0% {
    -webkit-transform: rotate(0deg);
            transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(360deg);
            transform: rotate(360deg);
  }
}
@keyframes swiper-preloader-spin {
  0% {
    -webkit-transform: rotate(0deg);
            transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(360deg);
            transform: rotate(360deg);
  }
}
.swiper .swiper-notification {
  position: absolute;
  left: 0;
  top: 0;
  pointer-events: none;
  opacity: 0;
  z-index: -1000;
}

.swiper-free-mode > .swiper-wrapper {
  transition-timing-function: ease-out;
  margin: 0 auto;
}

.swiper-grid > .swiper-wrapper {
  flex-wrap: wrap;
}

.swiper-grid-column > .swiper-wrapper {
  flex-wrap: wrap;
  flex-direction: column;
}

.swiper-fade.swiper-free-mode .swiper-slide {
  transition-timing-function: ease-out;
}
.swiper-fade .swiper-slide {
  pointer-events: none;
  transition-property: opacity;
}
.swiper-fade .swiper-slide {
  pointer-events: none;
}
.swiper-fade-active {
  pointer-events: auto;
}
.swiper-fade-active-active {
  pointer-events: auto;
}

.swiper-cube {
  overflow: visible;
}
.swiper-cube .swiper-slide {
  pointer-events: none;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  z-index: 1;
  visibility: hidden;
  -webkit-transform-origin: 0 0;
          transform-origin: 0 0;
  width: 100%;
  height: 100%;
}
.swiper-cube .swiper-slide {
  pointer-events: none;
}
.swiper-cube.swiper-rtl .swiper-slide {
  -webkit-transform-origin: 100% 0;
          transform-origin: 100% 0;
}
.swiper-cube-active {
  pointer-events: auto;
}
.swiper-cube-active-active {
  pointer-events: auto;
  pointer-events: auto;
  visibility: visible;
}
.swiper-cube-next {
  pointer-events: auto;
  visibility: visible;
}
.swiper-cube-next + .swiper-slide {
  pointer-events: auto;
  visibility: visible;
}
.swiper-cube-prev {
  pointer-events: auto;
  visibility: visible;
}
.swiper-cube-shadow-bottom, .swiper-cube .swiper-slide-shadow-left, .swiper-cube .swiper-slide-shadow-right, .swiper-cube .swiper-slide-shadow-top {
  z-index: 0;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
}
.swiper-cube .swiper-cube-shadow {
  position: absolute;
  left: 0;
  bottom: 0px;
  width: 100%;
  height: 100%;
  opacity: 0.6;
  z-index: 0;
}
.swiper-cube .swiper-cube-shadow:before {
  content: "";
  background: #000;
  position: absolute;
  left: 0;
  top: 0;
  bottom: 0;
  right: 0;
  -webkit-filter: blur(50px);
          filter: blur(50px);
}

.swiper-flip {
  overflow: visible;
}
.swiper-flip .swiper-slide {
  pointer-events: none;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  z-index: 1;
}
.swiper-flip .swiper-slide {
  pointer-events: none;
}
.swiper-flip-active {
  pointer-events: auto;
}
.swiper-flip-active-active {
  pointer-events: auto;
}
.swiper-flip-shadow-bottom, .swiper-flip .swiper-slide-shadow-left, .swiper-flip .swiper-slide-shadow-right, .swiper-flip .swiper-slide-shadow-top {
  z-index: 0;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
}

.swiper-creative .swiper-slide {
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  overflow: hidden;
  transition-property: opacity, height, -webkit-transform;
  transition-property: transform, opacity, height;
  transition-property: transform, opacity, height, -webkit-transform;
}

.swiper-cards {
  overflow: visible;
}
.swiper-cards .swiper-slide {
  -webkit-transform-origin: center bottom;
          transform-origin: center bottom;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  overflow: hidden;
}

body.page-id-244, body.single-artwork {
  color: white;
  background-color: #000;
}
body.page-id-244 *::-moz-selection, body.single-artwork *::-moz-selection {
  background: white;
  color: black;
}
body.page-id-244 *::selection, body.single-artwork *::selection {
  background: white;
  color: black;
}
body.page-id-244 .logo, body.single-artwork .logo {
  background: #000;
}
body.page-id-244 .logo a, body.single-artwork .logo a {
  color: #000;
}
body.page-id-244 .logo a svg, body.single-artwork .logo a svg {
  fill: white;
  background: black;
}
body.page-id-244 .logo a svg path, body.single-artwork .logo a svg path {
  fill: white;
}
@media (max-width: 1050px) {
  body.page-id-244 ul#primary-menu li a span, body.single-artwork ul#primary-menu li a span {
    color: black;
  }
}
body.page-id-244 ul#primary-menu li.current-menu-item, body.single-artwork ul#primary-menu li.current-menu-item {
  border-color: white !important;
}
body.page-id-244 ul#primary-menu li:hover a span.act, body.page-id-244 ul#primary-menu li.current-menu-item a span.act, body.single-artwork ul#primary-menu li:hover a span.act, body.single-artwork ul#primary-menu li.current-menu-item a span.act {
  color: white !important;
}
body.page-id-244 .header-header .logo__more, body.single-artwork .header-header .logo__more {
  color: transparent;
  -webkit-text-stroke-color: white;
}
body.page-id-244 .header-header #menu-mobile-button, body.single-artwork .header-header #menu-mobile-button {
  background: white;
  color: black;
  border-color: white;
}
body.page-id-244 .header-header .mainmenu__visitnow, body.single-artwork .header-header .mainmenu__visitnow {
  color: black;
  background: white;
}
@media (max-width: 1050px) {
  body.page-id-244 .header-header .mainmenu, body.single-artwork .header-header .mainmenu {
    background: linear-gradient(0deg, rgba(0, 0, 0, 0) 0%, rgb(0, 0, 0) 100%);
  }
}
body.page-id-244 .visitnow-mobile, body.single-artwork .visitnow-mobile {
  background: white;
  color: black;
}
body.page-id-244 #content, body.single-artwork #content {
  background-color: #000;
}
body.page-id-244 #content .marquee-container > div > .marquee3k, body.single-artwork #content .marquee-container > div > .marquee3k {
  color: transparent;
  -webkit-text-stroke-color: white;
}
body.page-id-244 #bg-colophon, body.single-artwork #bg-colophon {
  background-color: rgb(18, 18, 18);
}

body.single-experience .header-header .logo {
  background: transparent;
}
body.single-experience #primary {
  z-index: 10;
  padding: 0;
  width: 100%;
}
body.single-experience #content {
  padding-top: 0;
  min-height: 100vh;
}
body.single-experience #content .content-area {
  padding: 0;
}
body.single-experience #content .marquee-container {
  z-index: 0;
}
body.single-experience .single-experience {
  padding: 0 0px;
  height: 100vh;
  position: relative;
}
@media (max-width: 1050px) {
  body.single-experience .single-experience {
    height: calc(100vh - 85px);
  }
}
body.single-experience .single-experience p {
  max-width: 500px;
  display: inline-block;
}
body.single-experience .single-experience .exhibheader {
  left: calc(138px + 15vw);
}
@media (max-width: 1050px) {
  body.single-experience .single-experience .exhibheader {
    max-width: initial;
    left: 138px;
    bottom: 25px;
  }
}
body.single-experience .single-experience__header {
  display: inline-block;
  border-width: 0;
  margin-left: -133px;
  width: calc(100% + 133px);
  position: absolute;
  bottom: 0;
  background: white;
  overflow: hidden;
}
@media (max-width: 1050px) {
  body.single-experience .single-experience__header {
    font-weight: normal;
    width: calc(100% + 133px);
  }
}
body.single-experience .single-experience__header__video {
  width: 100%;
  height: 100vh;
  margin-left: 0;
}
@media (max-width: 1050px) {
  body.single-experience .single-experience__header__video {
    width: calc(100% - 7px);
    margin-left: 12px;
  }
}
body.single-experience .single-experience__header__video video {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
body.single-experience .single-experience__header__gradient {
  background: linear-gradient(0deg, rgb(255, 255, 255) 0%, rgba(255, 255, 255, 0) 10%);
  width: 100%;
  height: 100vh;
  position: absolute;
  top: 0;
  left: 0;
  z-index: 1;
}
body.single-experience .exhib-content {
  display: flex;
  padding: 0 0 520px 0;
}
@media (max-width: 1050px) {
  body.single-experience .exhib-content {
    display: block;
    padding-bottom: 72px;
  }
}
body.single-experience .exhib-content__meta {
  width: 15vw;
  padding: 5px 15px 15px 0;
  line-height: 1.1;
}
@media (max-width: 1050px) {
  body.single-experience .exhib-content__meta {
    width: 100%;
    font-size: 15px !important;
    padding-top: 15px;
  }
}
body.single-experience .exhib-content__meta div.meta_infos > div:first-child {
  margin-bottom: 9px;
}
body.single-experience .exhib-content__meta div.meta_infos > div:first-child > div:nth-child(2) {
  position: relative;
}
body.single-experience .exhib-content__meta div.meta_infos > div:first-child > div:nth-child(2):before {
  content: "->";
  position: absolute;
  top: 0;
  left: 0px;
}
body.single-experience .exhib-content__meta div.meta_infos > div:first-child > div:nth-child(3), body.single-experience .exhib-content__meta div.meta_infos > div:first-child > div:nth-child(2) {
  padding-left: 15px;
}
body.single-experience .exhib-content__meta div.meta_infos > div:nth-child(2) {
  padding-left: 15px;
  position: relativ;
}
body.single-experience .exhib-content__meta div.meta_infos > div:nth-child(2) > div {
  margin-bottom: 9px;
  position: relative;
}
body.single-experience .exhib-content__meta div.meta_infos > div:nth-child(2) > div:before {
  content: "->";
  position: absolute;
  top: 0;
  left: -15px;
}
body.single-experience .exhib-content__meta .info_header > div {
  padding: 6px 6px 3px;
  border: 1.5px solid;
  display: inline-block;
  margin-bottom: 9px;
}
body.single-experience .exhib-content__meta > div {
  padding: 0 8px 12px 8px;
  position: -webkit-sticky;
  position: sticky;
  top: 8px;
  min-height: 50vh;
  font-size: 15px;
  margin-top: 4px;
}
@media (max-width: 1050px) {
  body.single-experience .exhib-content__meta > div {
    position: static;
    min-height: initial;
    display: flex;
    border-top: 0 none;
    padding-left: 5px;
  }
}
body.single-experience .exhib-content__meta > div > * {
  margin-bottom: 12px;
}
@media (max-width: 1050px) {
  body.single-experience .exhib-content__meta > div > * {
    width: 50%;
    font-size: 15px !important;
  }
}
body.single-experience .exhib-content__meta > div > * h3 {
  font-size: 0.8rem;
  text-transform: none;
  border: 0 none;
  font-weight: bold;
  padding: 5px 0;
}
body.single-experience .exhib-content__meta > div .visitnow > a {
  display: inline-block;
  border: 1.5px solid black;
  padding: 7px 8px 4px 8px;
  background: white;
  font-weight: bold;
  margin-top: 15px;
}
body.single-experience .exhib-content__descr_text {
  width: calc(100% - 200px - 15vw);
  padding: 5px 5px;
}
@media (max-width: 1050px) {
  body.single-experience .exhib-content__descr_text {
    width: 100%;
  }
}
body.single-experience .exhib-content__descr_text #section-0 .block__headline {
  display: none;
}
body.single-experience .exhib-content__descr_text__subtitle {
  font-size: 1.6rem !important;
  border-top: 1.5px solid transparent;
  padding: 15px 0 0 0;
  margin-top: 19px;
  display: inline-block;
  font-weight: normal;
  line-height: 1.1;
}
body.single-experience .exhib-content__descr_text__artists {
  line-height: 1.4;
  width: calc(100% - 200px - 15vw);
}
body.single-experience .exhib-content__descr_text__artists__headline {
  font-weight: bold;
}
body.single-experience .exhib-content__descr_text > div > section:nth-child(1) > .block__headline {
  display: none;
}
body.single-experience .exhib-content .artists {
  padding: 0;
  line-height: 1.4;
}
@media (max-width: 1050px) {
  body.single-experience .exhib-content .artists {
    font-size: 18px;
  }
}
body.single-experience .exhib-content .artists ul > a:last-child span {
  display: none;
}

body.page-id-246 .header-header .logo {
  background: transparent;
}
body.page-id-246 #primary {
  z-index: 10;
  padding: 0;
  width: 100%;
}
body.page-id-246 #content {
  padding-top: 0;
  min-height: 100vh;
}
body.page-id-246 #content .content-area {
  padding: 0;
}
body.page-id-246 #content .marquee-container {
  z-index: 0;
}
body.page-id-246 .about {
  padding: 0 0px;
  height: 60vh;
  position: relative;
}
body.page-id-246 .about__viewer {
  width: 47vw;
  padding: 0 0 15px 0;
}
@media (max-width: 700px) {
  body.page-id-246 .about__viewer {
    height: initial;
  }
}
body.page-id-246 .about__viewer img {
  width: 100%;
  height: 100%;
  -o-object-fit: contain;
     object-fit: contain;
  -o-object-position: left top;
     object-position: left top;
}
body.page-id-246 .about p {
  max-width: 500px;
  display: inline-block;
}
body.page-id-246 .about__header {
  display: inline-block;
  border-width: 0;
  margin-left: -133px;
  width: calc(100% + 133px);
  border-radius: 15px;
  position: absolute;
  bottom: -9px;
  padding-bottom: 15px;
  background: white;
}
@media (max-width: 1050px) {
  body.page-id-246 .about__header {
    font-weight: normal;
    width: calc(100% + 133px);
  }
}
body.page-id-246 .about__header__infos {
  color: black;
  bottom: 30px;
  left: calc(138px + 15vw);
  display: inline-block;
  padding: 0;
  background: rgb(255, 205, 254);
  background: transparent;
  position: absolute;
  z-index: 10;
}
@media (max-width: 1050px) {
  body.page-id-246 .about__header__infos {
    max-width: initial;
    left: 138px;
    bottom: 25px;
  }
}
body.page-id-246 .about__header__infos__title {
  font-size: 1.2rem !important;
  padding: 10px 0px 0px 0px;
  text-align: left;
  line-height: 1.1;
  border-top: 1.5px solid black;
  display: inline-block;
  font-weight: 900;
}
@media (max-width: 1050px) {
  body.page-id-246 .about__header__infos__title {
    font-size: 56px;
  }
}
body.page-id-246 .about__header__infos__sub__subtitle, body.page-id-246 .about__header__infos__sub__location, body.page-id-246 .about__header__infos__sub__readmore {
  padding: 6px 9px 3px 9px;
  line-height: 1.1;
  border: 1.5px solid;
  margin-top: -1.5px;
  display: inline-block;
  background: white;
  font-size: 1.2rem;
  margin-right: -8px;
  border-color: black;
}
body.page-id-246 .about__header__infos__sub__subtitle br, body.page-id-246 .about__header__infos__sub__location br, body.page-id-246 .about__header__infos__sub__readmore br {
  display: none;
}
body.page-id-246 .about__header__infos__sub__readmore {
  transition: 0.3s color, 0.3s background;
}
body.page-id-246 .about__header__infos__sub__readmore:hover {
  background: black;
  color: white;
}
body.page-id-246 .about__header__video {
  width: 100%;
  height: 100vh;
  margin-left: 0;
}
@media (max-width: 1050px) {
  body.page-id-246 .about__header__video {
    width: calc(100% - 12px);
    margin-left: 12px;
  }
}
body.page-id-246 .about__header__video video {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
body.page-id-246 .about__header__gradient {
  background: linear-gradient(0deg, rgb(255, 255, 255) 0%, rgba(255, 255, 255, 0) 20%);
  width: 100%;
  height: 100vh;
  position: absolute;
  top: 0;
  left: 0;
  z-index: 1;
}
body.page-id-246 .exhib-content {
  display: flex;
  padding: 0 0 520px 0;
}
@media (max-width: 1050px) {
  body.page-id-246 .exhib-content {
    display: block;
    padding-bottom: 72px;
  }
}
body.page-id-246 .exhib-content__meta {
  width: 15vw;
  padding: 0px 15px 15px 0;
  border-top: 0 none;
  line-height: 1.1;
}
@media (max-width: 1050px) {
  body.page-id-246 .exhib-content__meta {
    width: 100%;
    font-size: 15px !important;
    padding-top: 15px;
  }
}
body.page-id-246 .exhib-content__meta .submenu {
  margin-bottom: 18px;
}
body.page-id-246 .exhib-content__meta .submenu li {
  margin-bottom: 3px;
}
body.page-id-246 .exhib-content__meta .exhibtype_header {
  padding: 6px 6px 3px;
  border: 1.5px solid;
  display: inline-block;
  margin-bottom: 9px;
}
body.page-id-246 .exhib-content__meta > div {
  padding: 0px 8px 12px 8px;
  position: -webkit-sticky;
  position: sticky;
  top: 8px;
  min-height: 50vh;
  font-size: 0.8rem;
  border-top: 0 none;
  margin-top: 4px;
}
@media (max-width: 1050px) {
  body.page-id-246 .exhib-content__meta > div {
    position: static;
    min-height: initial;
    display: flex;
    border-top: 0 none;
    padding-left: 5px;
  }
}
body.page-id-246 .exhib-content__meta > div > div {
  margin-bottom: 12px;
}
body.page-id-246 .exhib-content__meta > div > div h3 {
  font-size: 0.8rem;
  text-transform: none;
  border: 0 none;
  font-weight: bold;
  padding: 5px 0;
}
body.page-id-246 .exhib-content__meta > div .visitnow > a {
  display: inline-block;
  border: 1.5px solid black;
  padding: 7px 8px 4px 8px;
  background: white;
  font-weight: bold;
  margin-top: 15px;
}
body.page-id-246 .exhib-content__descr_text {
  width: calc(100% - 200px - 15vw);
  padding: 5px 5px;
}
@media (max-width: 1050px) {
  body.page-id-246 .exhib-content__descr_text {
    width: 100%;
  }
}
body.page-id-246 .exhib-content__descr_text #section-0 .block__headline {
  display: none;
}
body.page-id-246 .exhib-content__descr_text__subtitle {
  font-size: 1.6rem !important;
  border-top: 1.5px solid transparent;
  padding: 15px 0 0 0;
  margin-top: 19px;
  display: inline-block;
  font-weight: normal;
  line-height: 1.1;
}
body.page-id-246 .exhib-content__descr_text__artists {
  line-height: 1.4;
  width: calc(100% - 200px - 15vw);
}
body.page-id-246 .exhib-content__descr_text__artists__headline {
  font-weight: bold;
}
body.page-id-246 .exhib-content__descr_text > div > section:nth-child(1) > .block__headline {
  display: none;
}
body.page-id-246 .exhib-content .artists {
  padding: 0;
  line-height: 1.4;
  font-size: 1.1rem;
}
body.page-id-246 .exhib-content .artists ul > a:last-child span {
  display: none;
}

body #content .block-quotes {
  width: 100%;
  margin: 0 auto;
  padding: 30px 20px;
  margin-top: 36px;
  max-width: 100%;
  overflow: hidden;
}
@media (max-width: 1050px) {
  body #content .block-quotes {
    padding: 0px 0;
    align-items: center;
  }
}
body #content .block-quotes .quote {
  position: relative;
  width: 100%;
  height: 100%;
  display: flex;
  align-content: center;
}
body #content .block-quotes .quote > div {
  width: 100%;
}
body #content .block-quotes .quote > div > div {
  max-width: 1000px;
  margin: 0 auto;
}
@media (max-width: 1050px) {
  body #content .block-quotes .quote > div > div {
    max-width: 100%;
  }
}
body #content .block-quotes .quote__container {
  text-align: center;
  line-height: 1.1;
  text-align: center;
  padding: 2px 0 0 0;
  overflow: hidden;
  width: 100%;
}
body #content .block-quotes .quote__container__text {
  font-size: 6vw !important;
  font-family: "ABCGravity";
  text-transform: uppercase;
  padding: 0px 7px;
  background: black;
  color: white;
  display: inline;
  -webkit-box-decoration-break: clone;
          box-decoration-break: clone;
  max-width: 1000px;
  line-height: 1.3;
  line-height: 0.86 !important;
}
body #content .block-quotes .quote__container__text::before, body #content .block-quotes .quote__container__text::after {
  content: "";
  display: block;
  height: 0;
  width: 0;
}
body #content .block-quotes .quote__container__text::before {
  margin-bottom: calc(-0.2444444444em + 0px);
}
body #content .block-quotes .quote__container__text::after {
  margin-top: calc(-0.3194444444em + 0px);
}
@media (max-width: 1050px) {
  body #content .block-quotes .quote__container__text {
    max-width: 100%;
    font-size: 48px !important;
    line-height: 1.2;
  }
}
body #content .block-quotes .quote__container__text.quote-small {
  font-size: 4vw !important;
}
@media (max-width: 1050px) {
  body #content .block-quotes .quote__container__text.quote-small {
    font-size: 36px !important;
    padding: 0px 6px;
  }
}
body #content .block-quotes .quote__container__text br {
  display: none;
}
body #content .block-quotes .quote__meta {
  color: black;
  left: 0;
  width: 100%;
  padding: 24px 16px;
}
body #content .block-quotes .quote__meta__logo {
  width: 120px;
  margin: 0 auto;
}
body #content .block-quotes .quote__meta__name {
  font-size: 0.9rem;
  text-align: center;
  padding: 6px 12px;
}
body #content .block-quotes .quote__meta__subheadline {
  font-size: 0.9rem;
  text-align: center;
  padding: 6px 12px;
}

.block-logos .logos {
  margin: 0 auto;
  display: flex;
  flex-wrap: wrap;
}
.block-logos .logos__logo {
  padding: 0px 48px;
  align-items: center;
  align-self: middle;
  flex: 0 0 12.5%;
}
@media (max-width: 1100px) {
  .block-logos .logos__logo {
    flex: 0 0 25%;
  }
}
@media (max-width: 700px) {
  .block-logos .logos__logo {
    flex: 0 0 33.33%;
    padding: 0 24px;
  }
}
.block-logos .logos__logo img {
  -o-object-fit: contain;
     object-fit: contain;
  height: 180px;
}

#map {
  width: 50%;
  height: 100vh;
}

.videoelement {
  overflow: hidden;
  position: relative;
  font-size: 0;
}
.videoelement.video-loaded .videoelement__video {
  background: transparent !important;
}
.videoelement.video-loaded .videoelement__video__playbutton {
  display: none;
}
.videoelement.hasVideoSnippets .videoelement__snippetmenu {
  width: 300px;
  display: inline-block;
  vertical-align: top;
}
.videoelement.hasVideoSnippets .videoelement-container {
  width: calc(100% - 300px);
  display: inline-block;
  vertical-align: top;
}
.videoelement__video {
  background-size: contain;
  background-position: center center;
  background-repeat: no-repeat;
  position: relative;
  line-height: 0;
}
.videoelement__video__vid {
  position: relative;
}
.videoelement__video__vid iframe {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}
.videoelement__video__playbutton {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  pointer-events: none;
  z-index: 20;
  display: none;
}
.videoelement__video__playbutton > div {
  position: absolute;
  font-size: 1rem;
  left: 50%;
  top: 50%;
  color: black;
  text-transform: uppercase;
  margin-left: -31px;
  margin-top: -19px;
  background: white;
  padding: 9px 12px;
  color: white;
  transition: 0.3s background, 0.3s color;
  pointer-events: auto;
  cursor: pointer;
  line-height: 1.4;
}
.videoelement__video__playbutton > div:hover {
  background: white;
}
.videoelement__link-overlay {
  position: absolute;
  top: 0;
  left: 0;
  bottom: 18px;
  right: 0;
}
.videoelement__link-overlay a {
  line-height: 1;
  display: block;
  width: 100%;
  height: 100%;
  overflow: hidden;
  text-align: center;
}
.videoelement__link-overlay a:hover span {
  opacity: 0.5;
}
.videoelement__link-overlay a span {
  position: absolute;
  display: inline-block;
  bottom: 0;
  left: 50%;
  padding: 9px 12px;
  -webkit-transform: translateX(-50%);
          transform: translateX(-50%);
  transition: 0.3s opacity, 0.3s -webkit-transform;
  transition: 0.3s transform, 0.3s opacity;
  transition: 0.3s transform, 0.3s opacity, 0.3s -webkit-transform;
  text-transform: uppercase;
  font-size: 1rem;
  border: 1px solid;
  border-radius: 6px;
  margin-bottom: 12px;
  opacity: 0;
  color: black;
}
.videoelement__link-overlay a span:hover {
  opacity: 1;
}
.videoelement__mobile-caption {
  display: none;
  width: calc(100% - 135px);
  font-size: 1rem;
  vertical-align: top;
  padding: 12px 0;
}
.videoelement__mobile-caption p {
  margin: 0;
  padding: 0;
}
.videoelement__snippetmenu > ul {
  list-style-type: none;
  margin: 24px 0 0 0;
  padding: 0 12px;
}
.videoelement__snippetmenu > ul > li {
  font-size: 1.5rem;
  line-height: 1.1;
  cursor: pointer;
  padding: 12px 24px 12px 0px;
  position: relative;
  font-weight: 500;
  text-transform: uppercase;
}
.videoelement__snippetmenu > ul > li:nth-child(1) {
  z-index: 12;
  padding-top: 0px;
}
.videoelement__snippetmenu > ul > li:nth-child(2) {
  z-index: 11;
}
.videoelement__snippetmenu > ul > li:nth-child(3) {
  z-index: 10;
}
.videoelement__snippetmenu > ul > li:nth-child(4) {
  z-index: 9;
}
.videoelement__snippetmenu > ul > li.act:after {
  content: "";
  position: absolute;
  top: -12px;
  right: 48px;
  bottom: 12px;
  left: -24px;
  border-radius: 100%;
  border: 10px solid yellow;
  z-index: -1;
}

.devices {
  font-size: 0;
  width: 100%;
  display: flex;
  align-items: center;
  padding-left: 280px;
  margin-top: 60px;
}
@media (max-width: 1050px) {
  .devices {
    width: 100%;
    padding-left: 0;
    margin-top: 90px;
    display: block;
  }
}
.devices__intro {
  font-size: 21px;
  text-transform: uppercase;
  max-width: 40%;
  font-weight: bold;
}
@media (max-width: 1050px) {
  .devices__intro {
    font-weight: normal;
    text-transform: none;
    max-width: 100%;
    width: 100%;
  }
}
.devices__devices {
  max-width: 60%;
}
@media (max-width: 1050px) {
  .devices__devices {
    max-width: 100%;
  }
}
.devices > div {
  display: flex;
  position: relative;
  justify-content: flex-start;
}
@media (max-width: 700px) {
  .devices > div {
    display: initial !important;
  }
}

.device {
  width: 50%;
  position: relative;
  justify-content: flex-start;
  align-items: center;
  display: inline-block;
}
@media (max-width: 700px) {
  .device {
    width: 100%;
    text-align: center;
  }
}
.device img {
  opacity: 0.1;
  -webkit-filter: grayscale(1);
          filter: grayscale(1);
  width: 300px;
}
@media (max-width: 1050px) {
  .device img {
    width: 200px;
    margin: 0 auto;
  }
}
.device .versions {
  flex-direction: row;
  position: absolute;
  top: 50%;
  width: 100%;
  display: flex;
  padding: 12px;
  justify-content: center;
  align-items: center;
  margin-top: -27px;
}
.device .version {
  margin-left: 6px;
  text-align: center;
}
.device .version__logo {
  position: relative;
}
.device .version__logo > * {
  width: 100%;
  height: 100%;
  -o-object-fit: contain;
     object-fit: contain;
  line-height: 0;
}
.device .version .button {
  border: 1.5px solid;
  padding: 4px 18px 2px;
  border-radius: 45px;
  background: white;
  line-height: 1;
  font-size: 21px;
  transition: 0.1s background, 0.1s color, 0.3s -webkit-transform;
  transition: 0.1s background, 0.1s color, 0.3s transform;
  transition: 0.1s background, 0.1s color, 0.3s transform, 0.3s -webkit-transform;
}
.device .version .button:hover {
  background: black;
  color: white;
  border-color: black;
  -webkit-transform: scale(1.1);
          transform: scale(1.1);
}
.device .version .button.Coming {
  opacity: 0.5;
  pointer-events: none;
}

.block__videobackground {
  height: calc(100vh - 38px);
  width: 100%;
  padding: 9px;
}
.block__videobackground__video {
  width: 100%;
  height: 100%;
}
.block__videobackground__video video {
  -o-object-fit: cover;
     object-fit: cover;
  width: 100%;
  height: 100%;
}
.block__videobackground__login {
  position: absolute;
  right: 24px;
  top: 68px;
}
.block__videobackground__login > div {
  padding: 12px;
  background: white;
}
.block__videobackground__login > div .um-field-label, .block__videobackground__login > div label {
  display: none;
}
.block__videobackground__login > div .um-field {
  margin: 0 0 6px 0;
  padding: 0;
}
.block__videobackground__login > div .um-row {
  margin: 0 !important;
  padding: 0;
}
.block__videobackground__login > div .um-register {
  margin-bottom: 0 !important;
}

.memberships {
  display: flex;
  width: 100%;
}
.memberships h2 {
  font-size: 36px;
}
.memberships__leftcol {
  flex: 1 0 25%;
}
.memberships__leftcol .membership__intro {
  position: -webkit-sticky;
  position: sticky;
  top: 36px;
  flex: 1 0 25%;
  text-transform: uppercase;
}
.memberships__leftcol .membership__intro__text {
  padding: 12px;
}
.memberships__rightcol {
  flex: 1 0 75%;
  border-style: solid;
  border-color: #eee;
}
.memberships__rightcol h2 {
  position: -webkit-sticky;
  position: sticky;
  top: 36px;
  z-index: 10;
  background: white;
}
.memberships .membership__levels {
  opacity: 1;
  pointer-events: none;
}
.memberships .membership__levels > div {
  width: 100%;
  display: flex;
}
.memberships .membership__levels > div .membership {
  border-width: 0px 1px 1px 0;
  border-style: solid;
  border-color: #eee;
  flex: 1 0 25%;
  text-transform: uppercase;
  position: relative;
  padding-bottom: 122px;
}
.memberships .membership__levels > div .membership__intro {
  border-bottom: 0 none;
}
.memberships .membership__levels > div .membership__intro__text {
  padding: 12px;
}
.memberships .membership__levels > div .membership__top__image {
  width: 100%;
  height: auto;
  padding: 12px 12px 0px 12px !important;
}
.memberships .membership__levels > div .membership__top__image img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.memberships .membership__levels > div .membership__bottom {
  padding: 0px 12px 12px 12px;
}
.memberships .membership__levels > div .membership__bottom__buttons {
  position: absolute;
  bottom: 0;
  width: 100%;
  left: 0;
}
.memberships .membership__levels > div .membership__bottom__buttons__toptext {
  width: 100%;
  text-align: center;
  padding: 12px;
}
.memberships .membership__levels > div .membership__bottom__buttons__button {
  display: block;
}
.memberships .membership__levels > div .membership__bottom__buttons__button button {
  width: calc(100% - 60px);
  padding: 12px 12px;
  border: 0 none;
  border-radius: 0;
  font-size: 1rem;
  text-transform: uppercase;
  margin: 0 auto 24px;
  display: block;
  background: white;
  border: 1px solid black;
  border-radius: 136px;
  box-shadow: 6px 6px 12px rgba(55, 55, 55, 0.3);
  transition: 0.3s color, 0.3s background;
}
.memberships .membership__levels > div .membership__bottom__buttons__button button:hover {
  color: white;
  background: black;
}
.memberships .membership__levels > div .membership__bottom ul {
  list-style-type: disc;
  margin: 0 18px;
}
.memberships .membership__levels > div .membership__bottom ul li {
  padding: 6px 0;
}

#planetContainer {
  width: 100%;
  height: 100vh;
}

.block__vault-list {
  padding: 10px;
  margin-top: 72px;
  width: 100%;
  margin: 0 15px 0 0;
  padding: 0 0 0 0;
  position: relative;
  font-size: 21px;
  line-height: 1.1;
}
.block__vault-list__info__intro {
  margin-bottom: 30px;
  padding: 0px 15px 15px 0;
  display: inline-block;
  width: 33.33%;
  vertical-align: top;
}
@media (max-width: 1050px) {
  .block__vault-list__info__intro {
    width: 100%;
  }
}
.block__vault-list__info__wallets {
  margin-bottom: 30px;
  padding: 9px;
  border: 1.5px solid;
  display: inline-block;
  border-radius: 15px;
  width: 33.33%;
  vertical-align: top;
  font-size: 15px;
}
.block__vault-list__info__wallets > div {
  margin-bottom: 3px;
}
@media (max-width: 1050px) {
  .block__vault-list__info__wallets {
    width: 100%;
    overflow: hidden;
  }
}
.block__vault-list__artistlist {
  margin-bottom: 90px;
}
.block__vault-list__artistlist > div {
  display: flex;
}
@media (max-width: 1050px) {
  .block__vault-list__artistlist > div {
    display: flex;
    font-size: 15px;
    flex-wrap: wrap;
  }
}
.block__vault-list__artistlist > div > div {
  width: 16.66%;
  position: relative;
  z-index: 10;
  padding-right: 12px;
}
@media (max-width: 1050px) {
  .block__vault-list__artistlist > div > div {
    width: 33.33%;
  }
}
.block__vault-list__artistlist > div > div > *.firstletter {
  display: none;
  font-size: 48px;
  opacity: 1;
  font-weight: 300;
  z-index: -1;
}
.block__vault-list__artistlist > div > div.firstletter {
  line-heigt: 0.8;
  color: white;
  text-align: center;
  margin-right: 12px;
  margin-top: 24px;
  margin-left: -15px;
}
.block__vault-list__artistlist > div > div.firstletter:first-child {
  margin-top: 0;
}
.block__vault-list .collectionlist-container {
  width: 100%;
  margin: -10px 0 0 -10px;
  overflow: hidden;
}
.block__vault-list .collectionlist-container > div.artwork {
  width: 20%;
  padding: 5px;
}
@media (max-width: 1050px) {
  .block__vault-list .collectionlist-container > div.artwork {
    width: 50%;
    overflow: hidden;
    font-size: 15px;
  }
}
.block__vault-list .collectionlist-container > div.artwork.highlight {
  width: 40%;
}
.block__vault-list .collectionlist-container > div.artwork > * {
  background: rgb(18, 18, 18);
  width: 100%;
  display: block;
  line-height: 1.1;
  padding: 12px 12px 18px 12px;
  border: 1px solid rgba(0, 0, 0, 0.02);
  transition: 0.3s -webkit-transform;
  transition: 0.3s transform;
  transition: 0.3s transform, 0.3s -webkit-transform;
}
.block__vault-list .collectionlist-container > div.artwork > *:hover {
  -webkit-transform: scale(1.01, 1.01);
          transform: scale(1.01, 1.01);
}
.block__vault-list .collectionlist-container > div.artwork > *:hover .info {
  color: rgb(255, 255, 255);
}
.block__vault-list .collectionlist-container > div.artwork > *:hover .thumb img {
  -webkit-filter: grayscale(0);
          filter: grayscale(0);
}
.block__vault-list .collectionlist-container > div.artwork > * .thumb {
  margin-bottom: 12px;
}
.block__vault-list .collectionlist-container > div.artwork > * .thumb img {
  width: 100%;
  -webkit-filter: grayscale(1);
          filter: grayscale(1);
  transition: 0.3s -webkit-filter;
  transition: 0.3s filter;
  transition: 0.3s filter, 0.3s -webkit-filter;
}
.block__vault-list .collectionlist-container > div.artwork > * .artists {
  padding: 0;
  text-transform: uppercase;
  font-weight: bold;
}
.block__vault-list .collectionlist-container > div.artwork > * .info {
  display: inline-block;
  margin-top: 24px;
  border: 1.5px solid;
  padding: 3px 12px 2px;
  border-radius: 99px;
  line-height: 1;
  color: rgba(255, 255, 255, 0.3);
  transition: 0.3s color;
}
.block__vault-list .collectionlist-container > div.artwork img {
  background: rgba(0, 0, 0, 0.02);
  background-size: contain;
  border: 0 none;
}
.block__vault-list .collectionlist-container > div.artwork img[src=""] {
  content: url("data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==");
}
.block__vault-list .collectionlist-filters, .block__vault-list .collectionlist-sorting {
  float: left;
  display: none;
}
.block__vault-list .collectionlist-filters > div, .block__vault-list .collectionlist-sorting > div {
  padding: 12px 0;
}
.block__vault-list .collectionlist-filters > div > div, .block__vault-list .collectionlist-sorting > div > div {
  display: inline-block;
  margin-right: 3px;
  border: 1.5px solid;
  padding: 3px 12px 2px;
  border-radius: 99px;
  line-height: 1;
}
.block__vault-list .collectionlist-filters > div > div.filter-title, .block__vault-list .collectionlist-sorting > div > div.filter-title {
  border-color: transparent;
  padding: 3px 0 2px;
}
.block__vault-list .collectionlist-sorting {
  float: right;
}

.slideshowwide__block {
  height: calc(100vh - 185px);
  width: 100%;
  margin: 0px 15px 0 0;
  padding: 0 0 0 0;
  position: relative;
}
@media (max-width: 1050px) {
  .slideshowwide__block {
    height: calc(100vh - 165px);
  }
}
.slideshowwide__block .slideshow-container {
  position: static;
  top: initial;
  height: 100%;
  max-width: 100%;
  width: 100%;
  margin: 0;
}
.slideshowwide__block .slideshow-container .slideshowwide {
  height: 100%;
  overflow: hidden;
}
.slideshowwide__block .slideshow-container .slideshowwide .swiper-wrapper > .swiper-slide {
  width: calc(93vw - 45px);
  padding: 0;
  height: 100%;
  position: relative;
}
.slideshowwide__block .slideshow-container .slideshowwide .swiper-wrapper > .swiper-slide > div {
  display: initial !important;
  width: 100%;
}
.slideshowwide__block .slideshow-container .slideshowwide .swiper-wrapper > .swiper-slide > div video {
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.slideshowwide__block .slideshow-container .slideshowwide .swiper-wrapper > .swiper-slide > div > .bg-image {
  position: absolute;
  height: 100%;
  width: 100%;
}
.slideshowwide__block .slideshow-container .slideshowwide .swiper-wrapper > .swiper-slide > div > .bg-image img {
  height: 100%;
  width: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.slideshowwide__block .slideshow-container .slideshowwide .swiper-wrapper > .swiper-slide > div > .textcontainer {
  position: absolute;
  left: 24px;
  z-index: 10;
  color: white;
  bottom: 12px;
  font-size: 2vw;
  color: yellow;
  font-family: "ABCGRAVITY";
  z-index: 12;
  -webkit-text-stroke-width: 1px;
  -webkit-text-stroke-color: black;
  line-height: 0.9;
  right: 24px;
  text-align: center;
}
@media (max-width: 1050px) {
  .slideshowwide__block .slideshow-container .slideshowwide .swiper-wrapper > .swiper-slide > div > .textcontainer {
    font-size: 9vw;
  }
}

body.home .block__newsletter {
  width: calc(100% - 200px - 15vw);
  margin-left: 133px;
}
@media (max-width: 1050px) {
  body.home .block__newsletter {
    width: 100%;
    margin-left: 0;
  }
}

.block__newsletter {
  padding: 10px;
  margin: 0 0 72px 0;
  width: 100%;
  overflow: hidden;
  text-align: left;
}
@media (max-width: 700px) {
  .block__newsletter {
    display: initial;
  }
}
.block__newsletter__socials {
  display: flex;
}
@media (max-width: 1050px) {
  .block__newsletter__socials {
    flex-flow: wrap;
    flex: 0 0 50%;
  }
}
.block__newsletter__socials a {
  background: black;
  display: block;
  margin-right: 6px;
  margin-bottom: 3px;
  padding: 0px 11px;
  border-radius: 24px;
  transition: 0.3s -webkit-transform;
  transition: 0.3s transform;
  transition: 0.3s transform, 0.3s -webkit-transform;
}
.block__newsletter__socials a:hover {
  -webkit-transform: scale(1.05);
          transform: scale(1.05);
}
.block__newsletter__socials a > div.image {
  display: inline-block;
  width: 15px;
  height: 26px;
  vertical-align: middle;
}
.block__newsletter__socials a > div.image img {
  width: 100%;
  height: 100%;
  -o-object-fit: contain;
     object-fit: contain;
  margin-top: -1px;
}
.block__newsletter__socials a > div.title {
  display: inline-block;
  vertical-align: middle;
  color: white;
  font-size: 0.8rem;
  padding: 2px 8px 3px 7px;
  font-weight: bold;
}
@media (max-width: 1050px) {
  .block__newsletter__socials a > div.title {
    font-size: 0.6rem;
  }
}
.block__newsletter #mc_embed_signup {
  max-width: 600px;
  clear: both;
  border: 1.5px solid;
  padding: 12px 21px 10px;
  margin-bottom: 32px;
}
.block__newsletter #mc_embed_signup #mc_embed_signup_scroll > * {
  display: inline-block;
}
.block__newsletter .mc-field-group label {
  display: none;
}
.block__newsletter .mc-field-group input {
  font-size: 0.8rem;
  border: 0 none;
  border-bottom: 1.5px solid;
  margin: 14px 0;
  width: 100%;
  display: block;
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
  border-radius: 0;
  padding: 3px;
  min-width: 430px;
}
@media (max-width: 1050px) {
  .block__newsletter .mc-field-group input {
    min-width: 100%;
  }
}
.block__newsletter .mc-field-group input:focus {
  outline: 0;
}
.block__newsletter .button {
  padding: 4px 15px;
  border-radius: 25px;
  font-size: 0.8rem;
  font-weight: bold;
  background: black;
  color: white;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  border: 0 none;
  font-family: ABCDiatype, Helvetica, Arial, sans-serif;
  transition: 0.3s -webkit-transform;
  transition: 0.3s transform;
  transition: 0.3s transform, 0.3s -webkit-transform;
}
.block__newsletter .button:hover {
  -webkit-transform: scale(1.05);
          transform: scale(1.05);
}

.block__socials {
  margin-top: 10vw;
}
.block__socials__some {
  display: flex;
  padding: 6px;
  width: 100%;
}
@media (max-width: 700px) {
  .block__socials__some {
    flex-wrap: wrap;
  }
}
.block__socials__some__handle {
  display: inline-block;
  flex: 1 0 20%;
  text-align: center;
  padding: 12px;
}
@media (max-width: 700px) {
  .block__socials__some__handle {
    flex: 1 0 50%;
    max-width: 50%;
  }
}
.block__socials__some__handle:hover .block__socials__some__handle__title {
  background: black;
  color: white;
}
.block__socials__some__handle > div {
  padding: 12px;
  border-radius: 12px;
}
.block__socials__some__handle__title {
  border: 5px solid black;
  border-radius: 200px;
  font-weight: bold;
  transition: 0.3s black, 0.3s color;
  line-height: 1;
  padding: 7px;
}
@media (max-width: 700px) {
  .block__socials__some__handle__title {
    border-width: 3px;
  }
}
.block__socials__some__handle img {
  width: 60px;
  height: 60px;
}

.block__nftexternal .nftexternal {
  padding: 12px;
  display: flex;
  border-bottom: 2px solid;
}
@media (max-width: 700px) {
  .block__nftexternal .nftexternal {
    display: block;
  }
}
.block__nftexternal .nftexternal .bg-image {
  max-width: 33vw;
  line-height: 0;
}
@media (max-width: 700px) {
  .block__nftexternal .nftexternal .bg-image {
    max-width: 100%;
    width: 100%;
    margin-bottom: 12px;
  }
}
.block__nftexternal .nftexternal .bg-image img {
  line-height: 0;
  width: 33vw;
  height: 50vh;
  -o-object-fit: contain;
     object-fit: contain;
}
@media (max-width: 700px) {
  .block__nftexternal .nftexternal .bg-image img {
    max-width: 100%;
    width: 100%;
  }
}
.block__nftexternal .nftexternal__textcontainer {
  padding: 0 24px;
  width: 100%;
}
@media (max-width: 700px) {
  .block__nftexternal .nftexternal__textcontainer {
    padding: 0;
  }
}
.block__nftexternal .nftexternal__textcontainer p {
  margin: 0 0 12px 0 !important;
  padding: 0 !important;
  line-height: 1.15;
}
.block__nftexternal .nftexternal__textcontainer a {
  display: inline-block;
  border: 4px solid;
  font-weight: bold;
  border-radius: 90px;
  padding: 4px 30px 3px 30px;
  font-size: 36px;
  margin-top: 36px;
  line-height: 1;
  transition: 0.3s opacity, 0.3s background, 0.3s color;
  margin-top: 21px;
  margin: 72px 0 24px;
}
.block__nftexternal .nftexternal__textcontainer a:hover {
  background: black;
  color: white;
  border-color: black;
}
@media (max-width: 700px) {
  .block__nftexternal .nftexternal__textcontainer a {
    display: inline-block;
    border: 3px solid;
    font-weight: bold;
    border-radius: 90px;
    padding: 3px 15px 2px 15px;
    font-size: 21px;
    margin-top: 36px;
    line-height: 1;
    transition: 0.3s opacity, 0.3s background, 0.3s color;
    margin-top: 21px;
  }
  .block__nftexternal .nftexternal__textcontainer a:hover {
    background: black;
    color: white;
    border-color: black;
  }
}
.block__nftexternal .nftexternal__textcontainer__meta {
  display: flex;
  width: 100%;
  padding-right: 10vw;
}
@media (max-width: 700px) {
  .block__nftexternal .nftexternal__textcontainer__meta {
    display: block;
  }
}
.block__nftexternal .nftexternal__textcontainer__meta > * {
  margin-right: 64px;
  flex: 1 0 50%;
  display: flex;
  flex-direction: column;
}
.block__nftexternal .nftexternal__textcontainer__meta > * p {
  margin: 0 !important;
}
.block__nftexternal .nftexternal__textcontainer__meta > * span {
  display: inline-block;
}
.block__nftexternal .nftexternal h1, .block__nftexternal .nftexternal h2 {
  font-size: 6.5vw;
  margin: 0;
  padding: 0;
  text-transform: uppercase;
  display: inline;
  line-height: 0.8;
}
@media (max-width: 700px) {
  .block__nftexternal .nftexternal h1, .block__nftexternal .nftexternal h2 {
    font-size: 9vw;
  }
}
.block__nftexternal .nftexternal h2 {
  font-style: italic;
}

.experiences {
  padding: 0px;
  width: 100%;
}
.experiences .experience {
  width: calc(75% - 30px);
  padding: 8px;
  max-height: 100%;
  border-radius: 12px;
  display: inline-block;
  vertical-align: top;
  margin-right: 10px;
  position: relative;
  margin-bottom: 120px;
}
@media (max-width: 1050px) {
  .experiences .experience {
    width: 100%;
  }
}
.experiences .experience:hover .exhibheader {
  -webkit-transform: scale(1.02);
          transform: scale(1.02);
}
.experiences .experience:first-child {
  float: left;
  padding-left: 60px;
  margin-left: 20px;
}
@media (max-width: 1050px) {
  .experiences .experience:first-child {
    margin-left: 0;
    padding-left: 15px;
  }
}
.experiences .experience:first-child .exhibheader {
  left: -25px;
}
@media (max-width: 1050px) {
  .experiences .experience:first-child .exhibheader {
    top: 5px;
    bottom: initial;
    left: 5px;
  }
}
@media (max-width: 1050px) {
  .experiences .experience:first-child .experience__image {
    padding-top: 120px;
  }
}
.experiences .experience:nth-child(2) {
  float: right;
  margin-right: 20px;
}
@media (max-width: 1050px) {
  .experiences .experience:nth-child(2) {
    margin-right: 0px;
    padding-right: 15px;
    margin-top: 120px;
  }
}
.experiences .experience:nth-child(2) .exhibheader {
  top: -60px;
  left: initial;
  right: 60px;
  bottom: initial;
}
@media (max-width: 1050px) {
  .experiences .experience:nth-child(2) .exhibheader {
    top: -120px;
    right: 0;
  }
}
.experiences .experience:nth-last-child(2) {
  margin-bottom: 30px;
}
.experiences .experience__image {
  width: 100%;
  max-height: 60vh;
  padding: 0px 0 0px 0;
  max-height: 100%;
}
.experiences .experience__image img {
  -o-object-fit: cover;
     object-fit: cover;
  width: 100%;
  height: 100%;
}
.experiences .experience .exhibheader__sub__meta__readmore {
  display: none;
}

.artists {
  padding: 0 10px;
}
.artists > h2 {
  padding: 92px 0 0 0;
  margin: 0 !important;
}
@media (max-width: 700px) {
  .artists > h2 {
    padding-bottom: 12px;
    display: block;
  }
}
.artists ul {
  display: inline;
}
.artists ul > *:last-child {
  display: none;
}
.artists ul li {
  display: inline-block;
  line-height: 1;
}
.artists ul li a {
  display: inline-block;
  border-bottom: 2px solid;
}
.artists ul li:last-child span {
  display: none;
}

body.home .artworkslider__block {
  width: calc(100% - 200px - 15vw);
  margin-left: 133px;
}
@media (max-width: 1050px) {
  body.home .artworkslider__block {
    width: 100%;
    margin-left: 0;
  }
}

.artworkslider__block {
  padding: 60px 15px 90px 0;
  background: white;
  height: auto !important;
  width: 100%;
}
.artworkslider__block .slideshow-container {
  height: auto !important;
  position: static;
  top: initial;
  margin: 0;
  padding: 15px;
  z-index: 10;
  max-width: initial;
  background: rgba(0, 0, 0, 0.02);
  width: 100%;
}
.artworkslider__block .slideshow-container .artworkslider {
  overflow: hidden;
}
.artworkslider__block .slideshow-container .artworkslider .swiper-wrapper {
  height: initial !important;
  align-items: center;
}
.artworkslider__block .slideshow-container .artworkslider .swiper-wrapper > .swiper-slide {
  padding: 15px 30px;
  position: relative;
  text-align: center;
}
@media (max-width: 1050px) {
  .artworkslider__block .slideshow-container .artworkslider .swiper-wrapper > .swiper-slide {
    padding: 15px;
  }
}
.artworkslider__block .slideshow-container .artworkslider .swiper-wrapper > .swiper-slide > a {
  display: inline-block;
  text-align: left;
}
.artworkslider__block .slideshow-container .artworkslider .swiper-wrapper > .swiper-slide > a > .thumb img {
  box-shadow: 3px 3px 12px rgba(0, 0, 0, 0.1);
  background-size: contain;
  width: auto;
}
.artworkslider__block .slideshow-container .artworkslider .swiper-wrapper > .swiper-slide > a > .artists-slider {
  font-size: 0.8rem;
  line-height: 1.1;
  margin-top: 3px;
  font-weight: bold;
}
.artworkslider__block .slideshow-container .artworkslider .swiper-wrapper > .swiper-slide > a > .title {
  font-size: 0.8rem;
  line-height: 1.1;
  margin-top: 3px;
}
.artworkslider__block .slideshow-container .artworkslider .swiper-wrapper > .swiper-slide > a > .info {
  font-size: 0.8rem;
  display: none;
}
.artworkslider__block .slideshow-container .slider__nextarr, .artworkslider__block .slideshow-container .slider__prevarr {
  border: 1.5px solid;
  display: inline-block;
  width: 38px;
  line-height: 1;
  padding: 5px 2px 2px 2px;
  cursor: pointer;
  text-align: center;
  opacity: 0.1;
  transition: 0.3s opacity;
}
.artworkslider__block .slideshow-container .slider__nextarr::-moz-selection, .artworkslider__block .slideshow-container .slider__prevarr::-moz-selection {
  background: transparent !important;
}
.artworkslider__block .slideshow-container .slider__nextarr::selection, .artworkslider__block .slideshow-container .slider__prevarr::selection {
  background: transparent !important;
}
.artworkslider__block .slideshow-container .slider__nextarr:hover, .artworkslider__block .slideshow-container .slider__prevarr:hover {
  opacity: 1;
}
.artworkslider__block .slideshow-container .slider__prevarr {
  margin-left: 28px;
  margin-top: 25px;
}
@media (max-width: 1050px) {
  .artworkslider__block .slideshow-container .slider__prevarr {
    margin-left: 15px;
  }
}
.artworkslider__block .slideshow-container .slider__caption {
  opacity: 0.1;
  padding-top: 27px;
  padding-left: 6px;
  display: inline-block;
}

body #content .introblock {
  padding-left: 15px;
  position: relative;
  height: 80vh;
}
@media (max-width: 1050px) {
  body #content .introblock {
    padding-left: 0px;
    height: calc(100vh - 161px);
    margin-bottom: 140px;
  }
}
body #content .introblock__video {
  height: 100%;
  overflow: hidden;
}
body #content .introblock__video video {
  height: 102%;
  -o-object-fit: cover;
     object-fit: cover;
  width: 102%;
  margin-left: -1%;
  margin-top: -1%;
}
body #content .introblock__text {
  position: absolute;
  left: -5px;
  bottom: 60px;
}
@media (max-width: 1050px) {
  body #content .introblock__text {
    left: -5px;
    bottom: -145px;
  }
}
body #content .introblock__text__headline {
  margin: 0;
  padding: 0;
  text-align: left;
  background: transparent;
  line-height: 0.3;
  border: 0 none;
  max-width: 100%;
}
@media (max-width: 1050px) {
  body #content .introblock__text__headline {
    -webkit-text-stroke: 0px;
  }
}
body #content .introblock__text__headline span {
  width: initial;
  max-width: initial;
  display: inline-block;
  font-size: 8vw;
  font-family: "ABCGravity";
  color: black;
  background: white;
  line-height: 0.69;
  text-transform: uppercase;
  text-align: left;
  padding: 19px 15px 15px 15px;
  display: inline-block;
  border: 1.5px solid;
  margin: 0 0 -1.5px 0;
}
@media (max-width: 1050px) {
  body #content .introblock__text__headline span {
    width: initial;
    max-width: initial;
    display: inline-block;
    font-size: 8vw;
    color: black;
    background: white;
    line-height: 0.79;
    text-align: left;
    border: 1.5px solid black;
    font-size: 52px !important;
    font-weight: normal;
    letter-spacing: 0;
    -webkit-box-decoration-break: clone;
    padding: 9px 10px 7px 8px;
    margin-bottom: -2px;
  }
}
body #content .introblock__text__subheadline {
  width: initial;
  max-width: initial;
  margin: 0;
  display: block;
  padding: 0;
  background: white;
  padding: 15px 20px 11px 20px;
  border: 1.5px solid;
  white-space: nowrap;
}
@media (max-width: 1250px) {
  body #content .introblock__text__subheadline {
    padding: 15px 20px 15px 20px;
  }
}
@media (max-width: 1050px) {
  body #content .introblock__text__subheadline {
    white-space: normal;
    padding: 10px 14px 10px 11px;
    background: transparent;
    border: 0 none;
    margin-top: 20px;
  }
}
body #content .introblock__text__subheadline p {
  padding: 0 0px 0 0 !important;
  margin: 0;
  display: inline;
  line-height: 0.9;
  font-size: 21px;
}
@media (max-width: 1050px) {
  body #content .introblock__text__subheadline p {
    font-size: 18px;
    line-height: 1.3;
    display: inline-block;
  }
  body #content .introblock__text__subheadline p br {
    display: none;
  }
}
body #content .introblock__text__subheadline a {
  border: 1.5px solid;
  padding: 4px 14px 2px;
  border-radius: 45px;
  background: white;
  line-height: 1;
  font-size: 18px;
  transition: 0.1s background, 0.1s color, 0.3s -webkit-transform;
  transition: 0.1s background, 0.1s color, 0.3s transform;
  transition: 0.1s background, 0.1s color, 0.3s transform, 0.3s -webkit-transform;
  display: inline-block;
}
@media (min-width: 1600px) {
  body #content .introblock__text__subheadline a {
    font-size: 18px;
    line-height: 18px;
    padding: 3px 11px 2px;
    margin-top: -2px;
  }
}
body #content .introblock__text__subheadline a:hover {
  color: white;
  background: black;
  -webkit-transform: scale(1.05);
          transform: scale(1.05);
  border-color: black;
}
body #content .introblock__text__subheadline a > div {
  display: inline !important;
}

.highlights {
  padding: 15px 15px 75px 15px;
}
.highlights > div:nth-child(1) {
  width: 50%;
  display: inline-block;
  vertical-align: middle;
  padding-right: 15px;
}
@media (max-width: 1050px) {
  .highlights > div:nth-child(1) {
    width: 100%;
    text-align: left;
  }
}
.highlights > div:nth-child(1) > div:nth-child(1) {
  width: 70%;
  display: inline-block;
}
@media (max-width: 1050px) {
  .highlights > div:nth-child(1) > div:nth-child(1) {
    width: 90%;
  }
}
.highlights > div:nth-child(1) > div:nth-child(2) {
  width: 50%;
  display: inline-block;
}
@media (max-width: 1050px) {
  .highlights > div:nth-child(1) > div:nth-child(2) {
    width: 90%;
  }
}
.highlights > div:nth-child(2) {
  width: 50%;
  display: inline-block;
  vertical-align: middle;
  padding-left: 15px;
}
@media (max-width: 1050px) {
  .highlights > div:nth-child(2) {
    width: 100%;
  }
}
.highlights > div:nth-child(2) > div:nth-child(1) {
  width: 70%;
  display: inline-block;
}
@media (max-width: 1050px) {
  .highlights > div:nth-child(2) > div:nth-child(1) {
    width: 90%;
  }
}
.highlights__more {
  display: inline-block;
  border: 3px solid;
  font-weight: bold;
  border-radius: 90px;
  padding: 3px 15px 2px 15px;
  font-size: 21px;
  margin-top: 36px;
  line-height: 1;
  transition: 0.3s opacity, 0.3s background, 0.3s color;
  margin-top: 21px;
  margin: 0 auto;
  display: table;
  font-weight: normal;
  border-width: 1.5px;
}
.highlights__more:hover {
  background: black;
  color: white;
  border-color: black;
}
.highlights .highlight {
  width: 100%;
  max-width: 700px;
  margin-bottom: 72px;
}
@media (max-width: 1050px) {
  .highlights .highlight {
    margin-bottom: 30px;
  }
}
.highlights .highlight__artist {
  font-size: 0.8rem;
  line-height: 1.1;
  margin-top: 3px;
  font-weight: bold;
}
.highlights .highlight__title {
  font-size: 0.8rem;
  line-height: 1.1;
  margin-top: 3px;
}

.changelog .version {
  margin-bottom: 36px;
}
.changelog .version .date {
  font-size: 0.8rem !important;
  font-weight: bold;
  padding: 7px 9px 5px !important;
  display: inline-block;
  width: initial !important;
  border: 1.5px solid;
  margin-bottom: 12px;
  opacity: 0.3;
}
.changelog .version div {
  padding: 3px 0 12px 0;
}
.changelog .version ul {
  margin-bottom: 36px;
}
.changelog .version ul li {
  margin-bottom: 6px;
  padding-left: 24px;
  position: relative;
  max-width: 900px;
}
.changelog .version ul li:before {
  content: "";
  left: 0px;
  top: 13px;
  height: 1.5px;
  width: 18px;
  background: black;
  position: absolute;
}

body.home .visit {
  padding-left: 80px;
}
@media (max-width: 1050px) {
  body.home .visit {
    padding-left: 0;
  }
}

.visit {
  padding-bottom: 90px;
}
.visit.comingsoon a {
  pointer-events: none;
}
.visit__devices {
  display: flex;
}
@media (max-width: 1050px) {
  .visit__devices {
    display: block;
  }
}
.visit__devices__device {
  width: 33.33%;
  padding: 12px;
  position: relative;
  height: 400px;
  display: flex;
  align-items: center;
  justify-content: center;
  max-width: 410px;
}
@media (max-width: 1050px) {
  .visit__devices__device {
    max-width: 100%;
    width: 100%;
    height: 200px;
  }
}
.visit__devices__device > a {
  text-align: center;
  height: 300px;
  background: rgba(255, 255, 0, 0);
  display: flex;
  flex-direction: column;
  justify-content: center;
  border-radius: 100%;
  position: absolute;
  transition: 0.3s -webkit-transform;
  transition: 0.3s transform;
  transition: 0.3s transform, 0.3s -webkit-transform;
  cursor: pointer;
  align-items: center;
}
.visit__devices__device > a:hover {
  -webkit-transform: scale(1.05);
          transform: scale(1.05);
}
.visit__devices__device__headline {
  margin-bottom: -1.5px;
}
.visit__devices__device__headline > div {
  font-weight: bold;
  display: inline-block;
  border: 1.5px solid;
  padding: 3px 8px 0px;
  background: white;
  font-size: 27px;
}
.visit__devices__device__spatiallogo {
  margin: 12px 0;
}
.visit__devices__device__spatiallogo > svg {
  width: 80px !important;
  height: auto !important;
  opacity: 0.2;
}
.visit__devices__device__text {
  margin: 0;
  line-height: 1.1;
  font-size: 16px;
  background: white;
  border: 1.5px solid;
  display: inline-block;
  padding: 4px 7px;
  font-weight: bold;
}
.visit__devices__device__image {
  position: absolute;
  width: 100%;
  height: 100%;
  z-index: 0;
  padding: 40px;
  text-align: center;
}
.visit__devices__device__image img {
  max-width: 100%;
  height: 100%;
  -o-object-fit: contain;
     object-fit: contain;
}
.visit__info {
  display: flex;
  background: rgba(0, 0, 0, 0.02);
  padding: 15px;
  width: -webkit-fit-content;
  width: -moz-fit-content;
  width: fit-content;
}
@media (max-width: 1050px) {
  .visit__info {
    width: 100%;
    display: block;
    padding: 8px 12px 25px 12px;
  }
}
.visit__info__spatiallogo {
  padding: 8px 15px 8px 15px;
  opacity: 0.5;
}
@media (max-width: 1050px) {
  .visit__info__spatiallogo {
    padding: 8px 10px 8px 0px;
  }
}
.visit__info__text {
  padding: 0 20px 0 20px;
}
@media (max-width: 1050px) {
  .visit__info__text {
    padding: 0 5px;
  }
}
.visit__info__text__text {
  font-size: 16px;
  line-height: 1.3;
  opacity: 0.5;
  max-width: 900px;
}
@media (max-width: 1050px) {
  .visit__info__text__text {
    font-size: 15px;
  }
}
.visit__info__text__link {
  background: black;
  color: white;
  display: inline-block;
  padding: 4px 15px;
  border-radius: 25px;
  margin-top: 24px;
  font-size: 16px;
  font-weight: bold;
  transition: 0.3s -webkit-transform;
  transition: 0.3s transform;
  transition: 0.3s transform, 0.3s -webkit-transform;
}
@media (max-width: 1050px) {
  .visit__info__text__link {
    padding: 8px 16px 6px 16px;
  }
}
.visit__info__text__link:hover {
  -webkit-transform: scale(1.05);
          transform: scale(1.05);
}

body.home .programme {
  width: calc(100% - 200px - 15vw);
  margin-left: 133px;
}
@media (max-width: 1050px) {
  body.home .programme {
    margin-left: 0;
    width: 100%;
  }
}

.programme {
  overflow: hidden;
}
.programme .slider__prevarr {
  margin-left: 0;
}
.programme__event {
  padding: 0 20px 20px 0w;
}
.programme__event > div {
  padding: 0 20px 20px 0;
}
.programme__event > div > div {
  padding: 20px;
  height: 400px;
  font-size: 0.8rem;
  background: rgba(0, 0, 0, 0.02);
}
.programme__event > div > div h3 {
  border: 0 none;
  width: 100% !important;
  padding: 0 !important;
  max-width: 100% !important;
}
.programme__event > div > div p {
  padding: 0 !important;
}
.programme__event > div > div a {
  display: block;
  background: white;
  border: 1.5px solid black;
  display: inline-block;
  padding: 3px 12px;
  border-radius: 15px;
  margin-top: 24px;
  font-size: 16px;
  font-weight: bold;
  transition: 0.3s background, 0.3s color, 0.3s -webkit-transform;
  transition: 0.3s transform, 0.3s background, 0.3s color;
  transition: 0.3s transform, 0.3s background, 0.3s color, 0.3s -webkit-transform;
}
.programme__event > div > div a:hover {
  -webkit-transform: scale(1.05);
          transform: scale(1.05);
  background: black;
  color: white;
}

.entry-content .block__mr-presslinks {
  padding: 0 !important;
}
.entry-content .block__mr-presslinks .entry-content > * {
  border: 0 none !important;
}
.entry-content .block__mr-presslinks .content-container .header {
  display: flex !important;
  border-bottom: 1px solid black;
  text-transform: uppercase;
  position: -webkit-sticky;
  position: sticky;
  top: 82px;
  background: white;
}
.entry-content .block__mr-presslinks .content-container .header > * {
  flex: 1 1;
  overflow: hidden;
  padding: 12px 20px;
}
.entry-content .block__mr-presslinks .content-container .header > *:first-child {
  flex: 60px 0;
}
.entry-content .block__mr-presslinks .content-container .header > *:nth-child(2) {
  flex: calc(40% - 15px);
}
.entry-content .block__mr-presslinks .content-container .header > *:nth-child(3) {
  flex: calc(20% - 15px);
}
.entry-content .block__mr-presslinks .content-container .header > *:nth-child(4) {
  flex: calc(20% - 15px);
}
.entry-content .block__mr-presslinks .content-container .header > *:nth-child(5) {
  flex: calc(20% - 15px);
}
.entry-content .block__mr-presslinks .content-container > article {
  width: 100%;
  padding: 0;
  min-height: initial !important;
  border-bottom: 1px solid black;
}
.entry-content .block__mr-presslinks .content-container > article a {
  text-decoration: none;
  color: black;
  border: 0 none;
}
.entry-content .block__mr-presslinks .content-container > article a:hover {
  border: 0 none;
}
.entry-content .block__mr-presslinks .content-container > article > div {
  display: flex !important;
}
.entry-content .block__mr-presslinks .content-container > article > div > * {
  flex: 1 1;
  overflow: hidden;
}
.entry-content .block__mr-presslinks .content-container > article > div > *:first-child {
  flex: 60px 0;
}
.entry-content .block__mr-presslinks .content-container > article > div > *:nth-child(2) {
  flex: calc(40% - 15px);
}
.entry-content .block__mr-presslinks .content-container > article > div > *:nth-child(3) {
  flex: calc(20% - 15px);
}
.entry-content .block__mr-presslinks .content-container > article > div > *:nth-child(4) {
  flex: calc(20% - 15px);
}
.entry-content .block__mr-presslinks .content-container > article > div > *:nth-child(5) {
  flex: calc(20% - 15px);
}
.entry-content .block__mr-presslinks .content-container > article img {
  width: 100%;
  max-width: 180px;
  height: auto;
}
.entry-content .block__mr-presslinks .content-container > article button {
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  border: 1px solid black;
  background: white;
  padding: 3px 9px;
  text-transform: uppercase;
  display: block;
  margin: 9px 0;
  cursor: pointer;
  transition: 0.3s background, 0.3s color;
  font-size: 0.8em;
}
.entry-content .block__mr-presslinks .content-container > article button:hover {
  background: black;
  color: white;
}
.entry-content .block__mr-presslinks .content-container > article h3 {
  font-size: 1em !important;
  text-transform: uppercase;
  font-weight: normal;
  margin-bottom: 0;
  line-height: 1.05;
  margin: 0;
  padding: 0 36px 0 0;
}
.entry-content .block__mr-presslinks .content-container > article .footer-meta-content {
  font-size: 1em;
}

* {
  box-sizing: border-box;
}

body, html {
  height: 100%;
}

::-moz-selection {
  background: black;
  color: white;
}

::selection {
  background: black;
  color: white;
}

html {
  scroll-behavior: smooth;
  -webkit-text-size-adjust: 100%;
     -moz-text-size-adjust: 100%;
          text-size-adjust: 100%;
  text-rendering: optimizeLegibility;
  font-size: 21px;
  line-height: 1.25;
  font-family: ABCDiatype, Helvetica, Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
}
@media (max-width: 1050px) {
  html {
    font-size: 18px;
  }
}

body {
  padding: 0;
  margin: 0;
  color: #000;
  line-height: 1.4;
}
body.home .wp-block-image {
  width: calc(100% - 200px - 15vw);
  margin-left: 133px !important;
}
@media (max-width: 1050px) {
  body.home .wp-block-image {
    margin-left: 0 !important;
    width: 100%;
  }
}
body.windows #content .introblock__text__headline span {
  line-height: 1.3;
}
body.windows #content .introblock__text__headline span::before, body.windows #content .introblock__text__headline span::after {
  content: "";
  display: block;
  height: 0;
  width: 0;
}
body.windows #content .introblock__text__headline span::before {
  margin-bottom: calc(-0.2444444444em + 0px);
}
body.windows #content .introblock__text__headline span::after {
  margin-top: calc(-0.3194444444em + 0px);
}
body.windows .exhibheader__title div.title-desktop span {
  line-height: 1.3;
}
body.windows .exhibheader__title div.title-desktop span::before, body.windows .exhibheader__title div.title-desktop span::after {
  content: "";
  display: block;
  height: 0;
  width: 0;
}
body.windows .exhibheader__title div.title-desktop span::before {
  margin-bottom: calc(-0.2444444444em + 0px);
}
body.windows .exhibheader__title div.title-desktop span::after {
  margin-top: calc(-0.3194444444em + 0px);
}
body.windows.single-artwork .single-artwork__content .artist {
  line-height: 1.3;
  line-height: 0.8;
  padding-top: 2.2vw;
}
body.windows.single-artwork .single-artwork__content .artist::before, body.windows.single-artwork .single-artwork__content .artist::after {
  content: "";
  display: block;
  height: 0;
  width: 0;
}
body.windows.single-artwork .single-artwork__content .artist::before {
  margin-bottom: calc(-0.2444444444em + 0px);
}
body.windows.single-artwork .single-artwork__content .artist::after {
  margin-top: calc(-0.3194444444em + 0px);
}
body a {
  text-decoration: none;
  color: inherit;
  transition: 0.3s border-color;
  cursor: pointer;
}
body img {
  max-width: 100%;
  height: auto;
}
body p {
  margin-bottom: 0.5rem;
}
body p a {
  text-decoration: underline;
  text-decoration-thickness: 2px;
}
body h1 {
  line-height: 1;
  margin: 0;
  padding: 0;
  font-size: 1.667rem;
}
body h2, body h3 {
  max-width: 70%;
  font-size: 1.2rem !important;
  margin: 72px 0 20px 0px;
  font-weight: bold;
  border-top: 1.5px solid black;
  display: inline-block;
  padding: 15px 0 0 0;
}
@media (max-width: 1050px) {
  body h2, body h3 {
    font-size: 21px !important;
  }
}
body h4 {
  margin: 6px 0 12px 0;
  line-height: 1;
  font-size: 1.667rem;
}
body strong, body b {
  text-transform: uppercase;
}
body * {
  margin: 0;
  padding: 0;
}
body canvas {
  display: block;
}
body #container {
  width: 100vw;
  height: 100vh;
}
body #page {
  pointer-events: none;
  position: relative;
}
body #page > * {
  pointer-events: auto;
}
body #content {
  display: flex;
  width: 100%;
  justify-content: space-between;
  padding-top: 101px;
  padding-bottom: 15px;
  background: white;
  min-height: calc(100vh - 49px);
}
@media (max-width: 1050px) {
  body #content {
    padding-top: 64px;
  }
}
body #content blockquote {
  line-height: 1.1;
  text-align: center;
  display: block;
}
body #content blockquote p {
  font-size: 6vw !important;
  font-family: "ABCGravity";
  text-transform: uppercase;
  padding: 0px 32px;
  background: black;
  color: white;
  -webkit-box-decoration-break: clone;
          box-decoration-break: clone;
  display: inline-block;
  line-height: 0.97;
  max-width: 1000px;
  margin: 0 auto;
}
body #content blockquote cite {
  margin: 0;
}
body #content blockquote a {
  height: auto;
  padding: 9px 11px 7px;
  display: inline-block;
  margin-bottom: 0px;
  display: inline-block;
  z-index: 1;
  transition: opacity 0.3s;
  background: black;
  color: white;
  white-space: nowrap;
  letter-spacing: 0;
  border: 1.5px solid transparent;
  border-radius: 90px;
  font-weight: bold;
  background: white;
  color: black;
  border: 1.5px solid;
  margin-top: 12px;
  padding: 9px 16px 7px;
  border-radius: 30px;
}
@media (max-width: 1050px) {
  body #content blockquote a {
    font-size: 0.8rem;
    border: 0 none;
  }
}
body #content .marquee-container {
  display: block;
  text-shadow: none;
  color: black;
  line-height: 0.7;
  position: -webkit-sticky;
  position: sticky;
  width: 118px;
  height: calc(100vh - 22px);
  top: 8px;
  left: 5px;
  max-width: initial;
  text-align: left;
  font-family: ABCGravity;
  color: white;
  margin: 0;
  overflow: hidden;
  z-index: 100;
}
@media (max-width: 1050px) {
  body #content .marquee-container {
    width: 70px;
  }
}
body #content .marquee-container > div {
  -webkit-transform: rotate(-90deg);
          transform: rotate(-90deg);
  -webkit-transform-origin: left top;
          transform-origin: left top;
  left: 12px;
  position: absolute;
  bottom: -203px;
  position: absolute;
}
@media (max-width: 1050px) {
  body #content .marquee-container > div {
    left: 6px;
  }
}
body #content .marquee-container > div > .marquee3k {
  white-space: nowrap;
  font-size: 135px !important;
  -webkit-text-stroke-width: 1.5px;
  -webkit-text-stroke-color: black;
  text-transform: uppercase;
  margin: 0;
}
@media (max-width: 1050px) {
  body #content .marquee-container > div > .marquee3k {
    -webkit-text-stroke-width: 1px;
    letter-spacing: 1px;
    font-size: 75px !important;
  }
}
body #content .marquee-container > div > .marquee3k br {
  display: none;
}
body #content .intro-video {
  position: fixed;
  right: 120px;
  bottom: 80px;
  z-index: 200;
  display: none;
}
body #content .intro-video > div {
  padding: 15px 12px;
  background: white;
  border: 1px solid;
  box-shadow: 3px 3px 12px rgba(0, 0, 0, 0.6);
}
body #content .intro-video > div > div.subtext {
  font-family: "ABCGravity";
  font-size: 48px;
  text-transform: uppercase;
}
body #content > .content-area {
  width: calc(100% - 133px);
  padding: 0px 15px 0px 0;
}
@media (max-width: 1050px) {
  body #content > .content-area {
    width: calc(100% - 72px);
    padding: 0 8px 0px 0;
  }
}
body #content > .content-area .entry-content > div > div > section:nth-child(1) > .block__headline {
  display: none;
}
body #content #introvid {
  pointer-events: none;
}
body #content p {
  padding: 0px 15px 0 0;
  width: 100%;
  max-width: 100%;
  padding-right: 200px;
  font-size: 1.1rem;
  line-height: 1.4;
}
@media (max-width: 1050px) {
  body #content p {
    font-size: 18px;
    padding-right: 0;
  }
}
body #content .wp-block-image {
  padding: 0 0 15px;
  max-width: 1400px;
  margin: 0;
}
body #content .wp-block-image figcaption {
  font-size: 18px;
}
body #content .wp-block-image:last-child {
  margin: 0;
}
body #content .wp-block-columns {
  margin-bottom: 0;
}
body #content .wp-block-columns > div p:last-child {
  margin-bottom: 0;
}
body #content .wp-block-columns > div p {
  padding-right: 0;
}
body #content .wp-block-video {
  max-width: 1200px;
  margin: 0;
  overflow: hidden;
}
body #content .wp-block-video > video {
  margin-left: -1%;
  margin-top: -1%;
  width: 102%;
  height: 102%;
}

.entry-content > div section:nth-child(2) .block__headline {
  display: none;
}

#visitnow {
  position: absolute;
  top: calc(100vh - 300px);
  right: 0;
  bottom: 0;
  width: 350px;
  z-index: 100;
  pointer-events: none !important;
}
@media (max-width: 1050px) {
  #visitnow {
    top: 40vh;
    width: 150px;
  }
}
#visitnow:hover .visitnow__sphere {
  -webkit-transform: scale(1.05);
          transform: scale(1.05);
}
#visitnow .visitnow__container {
  position: -webkit-sticky;
  position: sticky;
  top: 200px;
  z-index: 12;
  width: 220px;
  height: 220px;
  background: white;
  border-radius: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
  font-size: 1.4rem;
  font-weight: bold;
  -webkit-transform: rotate(10deg);
          transform: rotate(10deg);
  box-shadow: 5px 5px 15px rgba(0, 0, 0, 0.4);
  flex-direction: column;
  pointer-events: auto;
}
@media (max-width: 1050px) {
  #visitnow .visitnow__container {
    top: 40px;
    width: 120px;
    height: 120px;
  }
}
#visitnow .visitnow__container:hover > a > div > div > div:first-child {
  opacity: 1 !important;
}
#visitnow .visitnow__container:hover > a > div > div > div:nth-child(2) {
  opacity: 0.2 !important;
}
#visitnow .visitnow__container > a {
  position: relative;
  display: block;
  width: 100%;
  height: 100%;
}
#visitnow .visitnow__container .visitnow__text {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 10;
  height: 100%;
  width: 100%;
  display: flex;
  justify-content: center;
  align-items: center;
  text-align: center;
  margin-top: 15px;
  color: black;
}
#visitnow .visitnow__container .visitnow__text > div > div:first-child {
  border: 1.5px solid;
  padding: 3px 12px 0px;
  background: white;
  font-size: 30px;
  margin-bottom: 6px;
  box-shadow: 5px 5px 15px rgba(0, 0, 0, 0.1);
  opacity: 0;
  transition: 0.3s opacity;
}
@media (max-width: 1050px) {
  #visitnow .visitnow__container .visitnow__text > div > div:first-child {
    opacity: 1;
    font-size: 13px;
    margin-bottom: 0px;
  }
}
#visitnow .visitnow__container .visitnow__text > div > div:nth-child(2) {
  opacity: 0;
  transition: 0.3s opacity;
  position: -webkit-sticky;
  position: sticky;
}
@media (max-width: 1050px) {
  #visitnow .visitnow__container .visitnow__text > div > div:nth-child(2) {
    opacity: 0.5;
  }
  #visitnow .visitnow__container .visitnow__text > div > div:nth-child(2) svg {
    width: 60px;
    height: 20px;
  }
}
#visitnow .visitnow__container .visitnow__sphere {
  width: 240px;
  height: 240px;
  position: absolute;
  opacity: 1;
  transition: 0.3s -webkit-transform;
  transition: 0.3s transform;
  transition: 0.3s transform, 0.3s -webkit-transform;
  --progress-bar-color: transparent;
  top: -10px;
  left: -10px;
}
@media (max-width: 1050px) {
  #visitnow .visitnow__container .visitnow__sphere {
    width: 130px;
    height: 130px;
  }
}

.slider__nextarr, .slider__prevarr {
  border: 1.5px solid;
  display: inline-block;
  width: 38px;
  line-height: 1;
  padding: 5px 2px 2px 2px;
  cursor: pointer;
  text-align: center;
  opacity: 0.1;
  transition: 0.3s opacity;
}
.slider__nextarr::-moz-selection, .slider__prevarr::-moz-selection {
  background: transparent !important;
}
.slider__nextarr::selection, .slider__prevarr::selection {
  background: transparent !important;
}
.slider__nextarr::-moz-selection:hover, .slider__prevarr::-moz-selection:hover {
  opacity: 1;
}
.slider__nextarr::selection:hover, .slider__prevarr::selection:hover {
  opacity: 1;
}
.slider__prevarr {
  margin-left: 28px;
  margin-top: 25px;
}
.slider__caption {
  opacity: 0.1;
  padding-top: 27px;
  padding-left: 6px;
  display: inline-block;
}

.regularGallery .swiper-wrapper {
  height: auto !important;
}
.regularGallery .swiper-wrapper figure {
  flex-shrink: 0;
  width: 100%;
  height: 100%;
  position: relative;
  transition-property: -webkit-transform;
  transition-property: transform;
  transition-property: transform, -webkit-transform;
}
.regularGallery .swiper-wrapper figure img {
  width: 100%;
}

.regularGallery-wrapper .slider__prevarr {
  margin-left: 0;
  margin-top: 0px;
}
.regularGallery-wrapper .slider__caption {
  padding-top: 0px;
}

.exhibheader {
  color: black;
  bottom: 30px;
  display: inline-block;
  padding: 0;
  position: absolute;
  z-index: 10;
  transition: 0.3s -webkit-transform;
  transition: 0.3s transform;
  transition: 0.3s transform, 0.3s -webkit-transform;
  line-height: 0.7;
}
.exhibheader__title {
  display: block;
  margin-bottom: -2px;
}
.exhibheader__title div.title-desktop span {
  font-size: 120px;
  text-transform: uppercase;
  font-family: ABCGravity;
  padding: 14px 12px 9px 10px;
  background: white;
  border: 1.5px solid black;
  display: inline-block;
}
@media (max-width: 1050px) {
  .exhibheader__title div.title-desktop span {
    display: none;
  }
}
.exhibheader__title div.title-mobile {
  display: none;
}
.exhibheader__title div.title-mobile span {
  font-size: 66px;
  padding: 10px 8px 7px 8px;
  text-transform: uppercase;
  font-family: ABCGravity;
  background: white;
  border: 1.5px solid black;
  display: inline-block;
  margin-top: -1.5px;
}
.exhibheader__title div.title-mobile span:first-child {
  margin-right: -1.5px;
}
@media (max-width: 1050px) {
  .exhibheader__title div.title-mobile {
    display: block;
  }
}
.exhibheader__sub {
  display: block;
  font-size: 1.2rem;
}
@media (max-width: 1050px) {
  .exhibheader__sub {
    font-size: 15px;
  }
}
.exhibheader__sub__subtitle .subtitle-desktop {
  display: block;
}
@media (max-width: 1050px) {
  .exhibheader__sub__subtitle .subtitle-desktop {
    display: none;
  }
}
.exhibheader__sub__subtitle .subtitle-desktop span {
  border: 1.5px solid;
  background: white;
  border-color: black;
  padding: 10px 11px 8px 11px;
  display: inline-block;
}
.exhibheader__sub__subtitle .subtitle-mobile {
  display: none !important;
}
@media (max-width: 1050px) {
  .exhibheader__sub__subtitle .subtitle-mobile {
    display: block !important;
  }
}
.exhibheader__sub__subtitle .subtitle-mobile span {
  display: block;
}
.exhibheader__sub__subtitle .subtitle-mobile span:nth-child(2) {
  margin-top: -1.5px;
}
.exhibheader__sub__subtitle .subtitle-mobile span > div {
  display: inline-block;
  border: 1.5px solid;
  background: white;
  border-color: black;
  padding: 8px 7px 7px 8px;
}
.exhibheader__sub__meta {
  display: block;
}
.exhibheader__sub__meta__location, .exhibheader__sub__meta__readmore {
  border: 1.5px solid;
  display: inline-block;
  background: white;
  border-color: black;
  margin-top: -1.5px;
  margin-right: -1.5px;
  padding: 10px 11px 8px 11px;
}
@media (max-width: 1050px) {
  .exhibheader__sub__meta__location, .exhibheader__sub__meta__readmore {
    padding: 8px 7px 7px 8px;
  }
}
.exhibheader__sub__meta__location br, .exhibheader__sub__meta__readmore br {
  display: none;
}
.exhibheader__sub__meta__readmore {
  transition: 0.3s color, 0.3s background;
}
.exhibheader__sub__meta__readmore:hover {
  background: black;
  color: white;
}

.submenu {
  margin-bottom: 18px;
}
.submenu .submenu_header {
  padding: 6px 6px 3px;
  border: 1.5px solid;
  display: inline-block;
  margin-bottom: 9px;
}
.submenu ul li {
  margin-bottom: 3px;
  padding-left: 15px;
}
@media (max-width: 1050px) {
  .submenu ul li {
    font-size: 15px !important;
  }
}
.submenu ul li a:hover {
  font-weight: bold;
}
.submenu ul li a.active, .submenu ul li a:hover {
  position: relative;
}
.submenu ul li a.active:before, .submenu ul li a:hover:before {
  content: "->";
  position: absolute;
  top: 1px;
  left: -15px;
}

/*# sourceMappingURL=style.css.map */